# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: spacex/api/device/rssi_scan.proto
# Protobuf Python Version: 5.29.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    3,
    '',
    'spacex/api/device/rssi_scan.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!spacex/api/device/rssi_scan.proto\x12\x11SpaceX.API.Device\"\x94\x01\n\tRssiEntry\x12!\n\x0ctheta_degree\x18\x01 \x01(\x01R\x0bthetaDegree\x12\x1d\n\nphi_degree\x18\x02 \x01(\x01R\tphiDegree\x12\x19\n\x08rssi_dbf\x18\x03 \x01(\x01R\x07rssiDbf\x12*\n\x11scan_timestamp_ms\x18\x04 \x01(\x04R\x0fscanTimestampMs\"0\n\x14\x44ishActivateRssiScan\x12\x18\n\x07\x63hannel\x18\x01 \x01(\rR\x07\x63hannel\"\xe7\x01\n\x15\x44ishGetRssiScanResult\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12\x18\n\x07\x63hannel\x18\x02 \x01(\rR\x07\x63hannel\x12+\n\x11request_timestamp\x18\x03 \x01(\x04R\x10requestTimestamp\x12%\n\x0enumber_samples\x18\x04 \x01(\rR\rnumberSamples\x12\x46\n\x10rssi_scan_points\x18\x05 \x03(\x0b\x32\x1c.SpaceX.API.Device.RssiEntryR\x0erssiScanPointsB\xd7\x01\n\x15\x63om.SpaceX.API.DeviceB\rRssiScanProtoP\x01ZIgithub.com/Eitol/starlink-client/libs/golang/client/gen/spacex/api/device\xa2\x02\x03SAD\xaa\x02\x11SpaceX.API.Device\xca\x02\x11SpaceX\\API\\Device\xe2\x02\x1dSpaceX\\API\\Device\\GPBMetadata\xea\x02\x13SpaceX::API::Deviceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'spacex.api.device.rssi_scan_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.SpaceX.API.DeviceB\rRssiScanProtoP\001ZIgithub.com/Eitol/starlink-client/libs/golang/client/gen/spacex/api/device\242\002\003SAD\252\002\021SpaceX.API.Device\312\002\021SpaceX\\API\\Device\342\002\035SpaceX\\API\\Device\\GPBMetadata\352\002\023SpaceX::API::Device'
  _globals['_RSSIENTRY']._serialized_start=57
  _globals['_RSSIENTRY']._serialized_end=205
  _globals['_DISHACTIVATERSSISCAN']._serialized_start=207
  _globals['_DISHACTIVATERSSISCAN']._serialized_end=255
  _globals['_DISHGETRSSISCANRESULT']._serialized_start=258
  _globals['_DISHGETRSSISCANRESULT']._serialized_end=489
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RssiEntry(_message.Message):
    __slots__ = ("theta_degree", "phi_degree", "rssi_dbf", "scan_timestamp_ms")
    THETA_DEGREE_FIELD_NUMBER: _ClassVar[int]
    PHI_DEGREE_FIELD_NUMBER: _ClassVar[int]
    RSSI_DBF_FIELD_NUMBER: _ClassVar[int]
    SCAN_TIMESTAMP_MS_FIELD_NUMBER: _ClassVar[int]
    theta_degree: float
    phi_degree: float
    rssi_dbf: float
    scan_timestamp_ms: int
    def __init__(self, theta_degree: _Optional[float] = ..., phi_degree: _Optional[float] = ..., rssi_dbf: _Optional[float] = ..., scan_timestamp_ms: _Optional[int] = ...) -> None: ...

class DishActivateRssiScan(_message.Message):
    __slots__ = ("channel",)
    CHANNEL_FIELD_NUMBER: _ClassVar[int]
    channel: int
    def __init__(self, channel: _Optional[int] = ...) -> None: ...

class DishGetRssiScanResult(_message.Message):
    __slots__ = ("success", "channel", "request_timestamp", "number_samples", "rssi_scan_points")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_FIELD_NUMBER: _ClassVar[int]
    REQUEST_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    NUMBER_SAMPLES_FIELD_NUMBER: _ClassVar[int]
    RSSI_SCAN_POINTS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    channel: int
    request_timestamp: int
    number_samples: int
    rssi_scan_points: _containers.RepeatedCompositeFieldContainer[RssiEntry]
    def __init__(self, success: bool = ..., channel: _Optional[int] = ..., request_timestamp: _Optional[int] = ..., number_samples: _Optional[int] = ..., rssi_scan_points: _Optional[_Iterable[_Union[RssiEntry, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: spacex/api/device/wifi_config.proto
# Protobuf Python Version: 5.29.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    3,
    '',
    'spacex/api/device/wifi_config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from spacex.api.device import command_pb2 as spacex_dot_api_dot_device_dot_command__pb2
from spacex.api.device import common_pb2 as spacex_dot_api_dot_device_dot_common__pb2
from spacex.api.device import wifi_util_pb2 as spacex_dot_api_dot_device_dot_wifi__util__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#spacex/api/device/wifi_config.proto\x12\x11SpaceX.API.Device\x1a\x1fspacex/api/device/command.proto\x1a\x1espacex/api/device/common.proto\x1a!spacex/api/device/wifi_util.proto\"\xdb\x02\n\nMeshConfig\x12!\n\x0c\x64isplay_name\x18\x01 \x01(\tR\x0b\x64isplayName\x12,\n\x12\x61pply_display_name\x18\x02 \x01(\x08R\x10\x61pplyDisplayName\x12/\n\x04\x61uth\x18\x03 \x01(\x0e\x32\x1b.SpaceX.API.Device.MeshAuthR\x04\x61uth\x12\x1d\n\napply_auth\x18\x04 \x01(\x08R\tapplyAuth\x12%\n\x0elast_connected\x18\x05 \x01(\x03R\rlastConnected\x12 \n\x0bincarnation\x18\x07 \x01(\x04R\x0bincarnation\x12)\n\x10hardware_version\x18\t \x01(\tR\x0fhardwareVersion\x12,\n\x12supports_5ghz_high\x18\n \x01(\x08R\x10supports5ghzHighJ\x04\x08\x06\x10\x07J\x04\x08\x08\x10\t\"\xb8\x42\n\nWifiConfig\x12!\n\x0c\x63ountry_code\x18\x03 \x01(\tR\x0b\x63ountryCode\x12-\n\x12\x61pply_country_code\x18\xbd\x08 \x01(\x08R\x10\x61pplyCountryCode\x12(\n\x10pin_country_code\x18\x35 \x01(\x08R\x0epinCountryCode\x12\x34\n\x16\x61pply_pin_country_code\x18\xbe\x08 \x01(\x08R\x13\x61pplyPinCountryCode\x12,\n\x12\x63ustom_power_table\x18\x36 \x01(\x08R\x10\x63ustomPowerTable\x12\x38\n\x18\x61pply_custom_power_table\x18\xbf\x08 \x01(\x08R\x15\x61pplyCustomPowerTable\x12%\n\x0esetup_complete\x18\x07 \x01(\x08R\rsetupComplete\x12\x31\n\x14\x61pply_setup_complete\x18\xf2\x07 \x01(\x08R\x12\x61pplySetupComplete\x12\x18\n\x07version\x18\t \x01(\rR\x07version\x12\x17\n\x07mac_wan\x18\x0c \x01(\tR\x06macWan\x12\x17\n\x07mac_lan\x18\r \x01(\tR\x06macLan\x12!\n\x0c\x63hannel_2ghz\x18\x13 \x01(\rR\x0b\x63hannel2ghz\x12-\n\x12\x61pply_channel_2ghz\x18\xf5\x07 \x01(\x08R\x10\x61pplyChannel2ghz\x12!\n\x0c\x63hannel_5ghz\x18\x14 \x01(\rR\x0b\x63hannel5ghz\x12-\n\x12\x61pply_channel_5ghz\x18\xf6\x07 \x01(\x08R\x10\x61pplyChannel5ghz\x12*\n\x11\x63hannel_5ghz_high\x18\x39 \x01(\rR\x0f\x63hannel5ghzHigh\x12\x36\n\x17\x61pply_channel_5ghz_high\x18\xf8\x07 \x01(\x08R\x14\x61pplyChannel5ghzHigh\x12Q\n\x0cmesh_configs\x18! \x03(\x0b\x32..SpaceX.API.Device.WifiConfig.MeshConfigsEntryR\x0bmeshConfigs\x12h\n\x14mesh_configs_updates\x18\xd9\x17 \x03(\x0b\x32\x35.SpaceX.API.Device.WifiConfig.MeshConfigsUpdatesEntryR\x12meshConfigsUpdates\x12-\n\x12\x61pply_mesh_configs\x18\x89\x08 \x01(\x08R\x10\x61pplyMeshConfigs\x12?\n\x0c\x64ynamic_keys\x18\x16 \x03(\x0b\x32\x1c.SpaceX.API.Device.PublicKeyR\x0b\x64ynamicKeys\x12,\n\x12\x61pply_dynamic_keys\x18\' \x01(\x08R\x10\x61pplyDynamicKeys\x12\x1f\n\x0bis_repeater\x18\x17 \x01(\x08R\nisRepeater\x12+\n\x11\x61pply_is_repeater\x18\x87\x08 \x01(\x08R\x0f\x61pplyIsRepeater\x12\x17\n\x07\x61p_mode\x18\x33 \x01(\x08R\x06\x61pMode\x12#\n\rapply_ap_mode\x18\xaa\x08 \x01(\x08R\x0b\x61pplyApMode\x12\x1f\n\x0bis_aviation\x18\x31 \x01(\x08R\nisAviation\x12+\n\x11\x61pply_is_aviation\x18\xa8\x08 \x01(\x08R\x0f\x61pplyIsAviation\x12\x1d\n\nboot_count\x18\x1a \x01(\x05R\tbootCount\x12\x30\n\x04\x62oot\x18\xb9\x17 \x01(\x0b\x32\x1b.SpaceX.API.Device.BootInfoR\x04\x62oot\x12 \n\x0bnameservers\x18\x1e \x03(\tR\x0bnameservers\x12,\n\x11\x61pply_nameservers\x18\x9e\x08 \x01(\x08R\x10\x61pplyNameservers\x12\x1d\n\nsecure_dns\x18\x32 \x01(\x08R\tsecureDns\x12)\n\x10\x61pply_secure_dns\x18\xa9\x08 \x01(\x08R\x0e\x61pplySecureDns\x12\x1f\n\x0b\x62ypass_mode\x18\x1f \x01(\x08R\nbypassMode\x12+\n\x11\x61pply_bypass_mode\x18\x9f\x08 \x01(\x08R\x0f\x61pplyBypassMode\x12\x1f\n\x0b\x64\x66s_enabled\x18* \x01(\x08R\ndfsEnabled\x12+\n\x11\x61pply_dfs_enabled\x18\xa2\x08 \x01(\x08R\x0f\x61pplyDfsEnabled\x12\x36\n\x17\x64isable_mesh_onboarding\x18\x34 \x01(\x08R\x15\x64isableMeshOnboarding\x12\x42\n\x1d\x61pply_disable_mesh_onboarding\x18\xab\x08 \x01(\x08R\x1a\x61pplyDisableMeshOnboarding\x12\x42\n\x08networks\x18\xcc\x08 \x03(\x0b\x32%.SpaceX.API.Device.WifiConfig.NetworkR\x08networks\x12&\n\x0e\x61pply_networks\x18\xcd\x08 \x01(\x08R\rapplyNetworks\x12 \n\x0bincarnation\x18+ \x01(\x04R\x0bincarnation\x12X\n\x12wireless_mode_2ghz\x18, \x01(\x0e\x32*.SpaceX.API.Device.WifiConfig.WirelessModeR\x10wirelessMode2ghz\x12\x38\n\x18\x61pply_wireless_mode_2ghz\x18\xa3\x08 \x01(\x08R\x15\x61pplyWirelessMode2ghz\x12X\n\x12wireless_mode_5ghz\x18- \x01(\x0e\x32*.SpaceX.API.Device.WifiConfig.WirelessModeR\x10wirelessMode5ghz\x12\x38\n\x18\x61pply_wireless_mode_5ghz\x18\xa4\x08 \x01(\x08R\x15\x61pplyWirelessMode5ghz\x12\x61\n\x17wireless_mode_5ghz_high\x18: \x01(\x0e\x32*.SpaceX.API.Device.WifiConfig.WirelessModeR\x14wirelessMode5ghzHigh\x12\x41\n\x1d\x61pply_wireless_mode_5ghz_high\x18\xae\x08 \x01(\x08R\x19\x61pplyWirelessMode5ghzHigh\x12U\n\x11ht_bandwidth_2ghz\x18. \x01(\x0e\x32).SpaceX.API.Device.WifiConfig.HTBandwidthR\x0fhtBandwidth2ghz\x12\x36\n\x17\x61pply_ht_bandwidth_2ghz\x18\xa5\x08 \x01(\x08R\x14\x61pplyHtBandwidth2ghz\x12U\n\x11ht_bandwidth_5ghz\x18/ \x01(\x0e\x32).SpaceX.API.Device.WifiConfig.HTBandwidthR\x0fhtBandwidth5ghz\x12\x36\n\x17\x61pply_ht_bandwidth_5ghz\x18\xa6\x08 \x01(\x08R\x14\x61pplyHtBandwidth5ghz\x12^\n\x16ht_bandwidth_5ghz_high\x18; \x01(\x0e\x32).SpaceX.API.Device.WifiConfig.HTBandwidthR\x13htBandwidth5ghzHigh\x12?\n\x1c\x61pply_ht_bandwidth_5ghz_high\x18\xaf\x08 \x01(\x08R\x18\x61pplyHtBandwidth5ghzHigh\x12O\n\rvht_bandwidth\x18\x30 \x01(\x0e\x32*.SpaceX.API.Device.WifiConfig.VHTBandwidthR\x0cvhtBandwidth\x12/\n\x13\x61pply_vht_bandwidth\x18\xa7\x08 \x01(\x08R\x11\x61pplyVhtBandwidth\x12\x61\n\x17vht_bandwidth_5ghz_high\x18< \x01(\x0e\x32*.SpaceX.API.Device.WifiConfig.VHTBandwidthR\x14vhtBandwidth5ghzHigh\x12\x41\n\x1d\x61pply_vht_bandwidth_5ghz_high\x18\xb0\x08 \x01(\x08R\x19\x61pplyVhtBandwidth5ghzHigh\x12.\n\x13use_public_services\x18\x37 \x01(\x08R\x11usePublicServices\x12:\n\x19\x61pply_use_public_services\x18\xac\x08 \x01(\x08R\x16\x61pplyUsePublicServices\x12@\n\x1c\x64isable_automated_speedtests\x18\x38 \x01(\x08R\x1a\x64isableAutomatedSpeedtests\x12L\n\"apply_disable_automated_speedtests\x18\xad\x08 \x01(\x08R\x1f\x61pplyDisableAutomatedSpeedtests\x12\x32\n\x15\x65nable_umbilical_vlan\x18= \x01(\x08R\x13\x65nableUmbilicalVlan\x12>\n\x1b\x61pply_enable_umbilical_vlan\x18\xb1\x08 \x01(\x08R\x18\x61pplyEnableUmbilicalVlan\x12\x44\n\x0c\x63lient_names\x18> \x03(\x0b\x32\x1d.SpaceX.API.Device.ClientNameB\x02\x18\x01R\x0b\x63lientNames\x12\x31\n\x12\x61pply_client_names\x18\xb2\x08 \x01(\x08\x42\x02\x18\x01R\x10\x61pplyClientNames\x12!\n\x0coutdoor_mode\x18? \x01(\x08R\x0boutdoorMode\x12-\n\x12\x61pply_outdoor_mode\x18\xb3\x08 \x01(\x08R\x10\x61pplyOutdoorMode\x12!\n\x0c\x64isable_2ghz\x18@ \x01(\x08R\x0b\x64isable2ghz\x12-\n\x12\x61pply_disable_2ghz\x18\xb4\x08 \x01(\x08R\x10\x61pplyDisable2ghz\x12!\n\x0c\x64isable_5ghz\x18\x41 \x01(\x08R\x0b\x64isable5ghz\x12-\n\x12\x61pply_disable_5ghz\x18\xb5\x08 \x01(\x08R\x10\x61pplyDisable5ghz\x12*\n\x11\x64isable_5ghz_high\x18\x42 \x01(\x08R\x0f\x64isable5ghzHigh\x12\x36\n\x17\x61pply_disable_5ghz_high\x18\xb6\x08 \x01(\x08R\x14\x61pplyDisable5ghzHigh\x12\x35\n\x17\x64isable_x_mesh_backhaul\x18\x43 \x01(\x08R\x14\x64isableXMeshBackhaul\x12\x41\n\x1d\x61pply_disable_x_mesh_backhaul\x18\xb7\x08 \x01(\x08R\x19\x61pplyDisableXMeshBackhaul\x12%\n\x0cgolden_bssid\x18\x44 \x01(\tB\x02\x18\x01R\x0bgoldenBssid\x12\x31\n\x12\x61pply_golden_bssid\x18\xb8\x08 \x01(\x08\x42\x02\x18\x01R\x10\x61pplyGoldenBssid\x12L\n\x11golden_iface_type\x18\x45 \x01(\x0e\x32\x1c.SpaceX.API.Device.IfaceTypeB\x02\x18\x01R\x0fgoldenIfaceType\x12:\n\x17\x61pply_golden_iface_type\x18\xb9\x08 \x01(\x08\x42\x02\x18\x01R\x14\x61pplyGoldenIfaceType\x12N\n\x13tx_power_level_2ghz\x18\x46 \x01(\x0e\x32\x1f.SpaceX.API.Device.TxPowerLevelR\x10txPowerLevel2ghz\x12\x39\n\x19\x61pply_tx_power_level_2ghz\x18\xba\x08 \x01(\x08R\x15\x61pplyTxPowerLevel2ghz\x12N\n\x13tx_power_level_5ghz\x18G \x01(\x0e\x32\x1f.SpaceX.API.Device.TxPowerLevelR\x10txPowerLevel5ghz\x12\x39\n\x19\x61pply_tx_power_level_5ghz\x18\xbb\x08 \x01(\x08R\x15\x61pplyTxPowerLevel5ghz\x12W\n\x18tx_power_level_5ghz_high\x18H \x01(\x0e\x32\x1f.SpaceX.API.Device.TxPowerLevelR\x14txPowerLevel5ghzHigh\x12\x42\n\x1e\x61pply_tx_power_level_5ghz_high\x18\xbc\x08 \x01(\x08R\x19\x61pplyTxPowerLevel5ghzHigh\x12\x41\n\x1d\x64isable_pending_update_reboot\x18I \x01(\x08R\x1a\x64isablePendingUpdateReboot\x12M\n#apply_disable_pending_update_reboot\x18\xc0\x08 \x01(\x08R\x1f\x61pplyDisablePendingUpdateReboot\x12\x46\n\x0e\x63lient_configs\x18J \x03(\x0b\x32\x1f.SpaceX.API.Device.ClientConfigR\rclientConfigs\x12\x31\n\x14\x61pply_client_configs\x18\xc1\x08 \x01(\x08R\x12\x61pplyClientConfigs\x12S\n\'disable_set_wifi_config_from_controller\x18K \x01(\x08R\"disableSetWifiConfigFromController\x12_\n-apply_disable_set_wifi_config_from_controller\x18\xc2\x08 \x01(\x08R\'applyDisableSetWifiConfigFromController\x12\x1d\n\nclient_key\x18L \x01(\x0cR\tclientKey\x12)\n\x10\x61pply_client_key\x18\xc3\x08 \x01(\x08R\x0e\x61pplyClientKey\x12[\n\x16wan_no_traffic_control\x18\xa1\x1f \x01(\x0b\x32#.SpaceX.API.Device.NoTrafficControlH\x00R\x13wanNoTrafficControl\x12T\n\x13wan_ack_suppression\x18\xa2\x1f \x01(\x0b\x32!.SpaceX.API.Device.AckSuppressionH\x00R\x11wanAckSuppression\x12R\n\x13wan_cake_rate_limit\x18\xa3\x1f \x01(\x0b\x32 .SpaceX.API.Device.CakeRateLimitH\x00R\x10wanCakeRateLimit\x12:\n\x19\x61pply_wan_traffic_control\x18\xc4\x08 \x01(\x08R\x16\x61pplyWanTrafficControl\x12+\n\x12wan_host_dscp_mark\x18M \x01(\x05R\x0fwanHostDscpMark\x12\x37\n\x18\x61pply_wan_host_dscp_mark\x18\xc5\x08 \x01(\x08R\x14\x61pplyWanHostDscpMark\x12&\n\x0f\x64\x65\x62ug_pop_pings\x18O \x01(\x08R\rdebugPopPings\x12\x32\n\x15\x61pply_debug_pop_pings\x18\xc7\x08 \x01(\x08R\x12\x61pplyDebugPopPings\x12#\n\rclient_tester\x18P \x01(\x08R\x0c\x63lientTester\x12/\n\x13\x61pply_client_tester\x18\xc8\x08 \x01(\x08R\x11\x61pplyClientTester\x12\x10\n\x03tag\x18N \x01(\rR\x03tag\x1a]\n\x10MeshConfigsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x33\n\x05value\x18\x02 \x01(\x0b\x32\x1d.SpaceX.API.Device.MeshConfigR\x05value:\x02\x38\x01\x1a\x64\n\x17MeshConfigsUpdatesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x33\n\x05value\x18\x02 \x01(\x0b\x32\x1d.SpaceX.API.Device.MeshConfigR\x05value:\x02\x38\x01\x1a\xde\x04\n\x0f\x42\x61sicServiceSet\x12\x15\n\x05\x62ssid\x18\xeb\x07 \x01(\tR\x05\x62ssid\x12\x13\n\x04ssid\x18\xed\x07 \x01(\tR\x04ssid\x12;\n\tauth_open\x18\xd1\x0f \x01(\x0b\x32\x1b.SpaceX.API.Device.AuthOpenH\x00R\x08\x61uthOpen\x12;\n\tauth_wpa2\x18\xd2\x0f \x01(\x0b\x32\x1b.SpaceX.API.Device.AuthWpa2H\x00R\x08\x61uthWpa2\x12;\n\tauth_wpa3\x18\xd3\x0f \x01(\x0b\x32\x1b.SpaceX.API.Device.AuthWpa3H\x00R\x08\x61uthWpa3\x12H\n\x0e\x61uth_wpa2_wpa3\x18\xd4\x0f \x01(\x0b\x32\x1f.SpaceX.API.Device.AuthWpa2Wpa3H\x00R\x0c\x61uthWpa2Wpa3\x12\x41\n\x0b\x61uth_radius\x18\xd5\x0f \x01(\x0b\x32\x1d.SpaceX.API.Device.AuthRadiusH\x00R\nauthRadius\x12\x37\n\x04\x62\x61nd\x18\xf3\x07 \x01(\x0e\x32\".SpaceX.API.Device.WifiConfig.BandR\x04\x62\x61nd\x12\x1e\n\niface_name\x18\xf9\x07 \x01(\tR\tifaceName\x12\x19\n\x07\x64isable\x18\xf5\x07 \x01(\x08R\x07\x64isable\x12\x17\n\x06hidden\x18\xf7\x07 \x01(\x08R\x06hiddenB\x06\n\x04\x61uthJ\x06\x08\xe8\x07\x10\xe9\x07J\x06\x08\xe9\x07\x10\xea\x07J\x06\x08\xea\x07\x10\xeb\x07J\x06\x08\xec\x07\x10\xed\x07J\x06\x08\xee\x07\x10\xef\x07J\x06\x08\xd0\x0f\x10\xd1\x0fJ\x06\x08\xf4\x07\x10\xf5\x07J\x06\x08\xf6\x07\x10\xf7\x07J\x06\x08\xf8\x07\x10\xf9\x07\x1a\x80\x04\n\x07Network\x12\x13\n\x04ipv4\x18\xeb\x07 \x01(\tR\x04ipv4\x12\"\n\x0c\x64hcpv4_start\x18\xf4\x07 \x01(\rR\x0b\x64hcpv4Start\x12$\n\rdhcp_disabled\x18\xf7\x07 \x01(\x08R\x0c\x64hcpDisabled\x12\x36\n\x17\x64hcpv4_lease_duration_s\x18\xf8\x07 \x01(\rR\x14\x64hcpv4LeaseDurationS\x12\x17\n\x06\x64omain\x18\xf3\x07 \x01(\tR\x06\x64omain\x12\\\n\x12\x62\x61sic_service_sets\x18\xef\x07 \x03(\x0b\x32-.SpaceX.API.Device.WifiConfig.BasicServiceSetR\x10\x62\x61sicServiceSets\x12*\n\x10\x63lient_isolation\x18\xf0\x07 \x01(\x08R\x0f\x63lientIsolation\x12\x15\n\x05guest\x18\xf1\x07 \x01(\x08R\x05guest\x12\x19\n\x07landing\x18\xf2\x07 \x01(\tR\x07landing\x12\'\n\x0flanding_page_v2\x18\xf9\x07 \x01(\x08R\rlandingPageV2\x12\x1b\n\x08internal\x18\xf5\x07 \x01(\x08R\x08internal\x12\x13\n\x04vlan\x18\xf6\x07 \x01(\rR\x04vlanJ\x06\x08\xe8\x07\x10\xe9\x07J\x06\x08\xe9\x07\x10\xea\x07J\x06\x08\xea\x07\x10\xeb\x07J\x06\x08\xec\x07\x10\xed\x07J\x06\x08\xed\x07\x10\xee\x07J\x06\x08\xee\x07\x10\xef\x07\"9\n\x08Security\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04WPA2\x10\x01\x12\x08\n\x04WPA3\x10\x02\x12\x0c\n\x08WPA2WPA3\x10\x03\"B\n\x04\x42\x61nd\x12\x0e\n\nRF_UNKNOWN\x10\x00\x12\x0b\n\x07RF_2GHZ\x10\x02\x12\x0b\n\x07RF_5GHZ\x10\x05\x12\x10\n\x0cRF_5GHZ_HIGH\x10\x06\"\xe5\x01\n\x0cWirelessMode\x12\x19\n\x15WIRELESS_MODE_DEFAULT\x10\x00\x12\n\n\x06\x41_ONLY\x10\x01\x12\n\n\x06\x42_ONLY\x10\x02\x12\n\n\x06G_ONLY\x10\x03\x12\n\n\x06N_ONLY\x10\x04\x12\r\n\tB_G_MIXED\x10\x05\x12\r\n\tA_N_MIXED\x10\x06\x12\r\n\tG_N_MIXED\x10\x07\x12\x0f\n\x0b\x42_G_N_MIXED\x10\x08\x12\x11\n\rA_AN_AC_MIXED\x10\t\x12\x0f\n\x0b\x41N_AC_MIXED\x10\n\x12\x12\n\x0e\x42_G_N_AX_MIXED\x10\x0b\x12\x14\n\x10\x41_AN_AC_AX_MIXED\x10\x0c\"_\n\x0bHTBandwidth\x12\x18\n\x14HT_BANDWIDTH_DEFAULT\x10\x00\x12\x17\n\x13HT_BANDWIDTH_20_MHZ\x10\x01\x12\x1d\n\x19HT_BANDWIDTH_20_OR_40_MHZ\x10\x02\"\x9c\x01\n\x0cVHTBandwidth\x12\x19\n\x15VHT_BANDWIDTH_DEFAULT\x10\x00\x12\x1a\n\x16VHT_BANDWIDTH_DISABLED\x10\x01\x12\x18\n\x14VHT_BANDWIDTH_80_MHZ\x10\x02\x12\x19\n\x15VHT_BANDWIDTH_160_MHZ\x10\x03\x12 \n\x1cVHT_BANDWIDTH_80_PLUS_80_MHZ\x10\x04\x42\x15\n\x13wan_traffic_controlJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07J\x04\x08\x08\x10\tJ\x04\x08\n\x10\x0bJ\x04\x08\x0b\x10\x0cJ\x04\x08\x0e\x10\x0fJ\x04\x08\x0f\x10\x10J\x04\x08\x10\x10\x11J\x04\x08\x11\x10\x12J\x04\x08\x12\x10\x13J\x04\x08\x15\x10\x16J\x04\x08\x18\x10\x19J\x04\x08\x19\x10\x1aJ\x04\x08\x1b\x10\x1cJ\x04\x08\x1c\x10\x1dJ\x04\x08\x1d\x10\x1eJ\x04\x08 \x10!J\x04\x08\"\x10#J\x04\x08#\x10$J\x04\x08$\x10%J\x04\x08%\x10&J\x04\x08&\x10\'J\x04\x08(\x10)J\x04\x08)\x10*J\x06\x08\xe9\x07\x10\xea\x07J\x06\x08\xea\x07\x10\xeb\x07J\x06\x08\xeb\x07\x10\xec\x07J\x06\x08\xec\x07\x10\xed\x07J\x06\x08\xed\x07\x10\xee\x07J\x06\x08\xee\x07\x10\xef\x07J\x06\x08\xef\x07\x10\xf0\x07J\x06\x08\xf0\x07\x10\xf1\x07J\x06\x08\xf1\x07\x10\xf2\x07J\x06\x08\xf3\x07\x10\xf4\x07J\x06\x08\xf4\x07\x10\xf5\x07J\x06\x08\xf7\x07\x10\xf8\x07J\x06\x08\xfd\x07\x10\xfe\x07J\x06\x08\x91\x08\x10\x92\x08J\x06\x08\x9b\x08\x10\x9c\x08J\x06\x08\x9c\x08\x10\x9d\x08J\x06\x08\x9d\x08\x10\x9e\x08J\x06\x08\xa0\x08\x10\xa1\x08J\x06\x08\xa1\x08\x10\xa2\x08J\x06\x08\xd1\x0f\x10\xd2\x0fJ\x06\x08\xd2\x0f\x10\xd3\x0fJ\x06\x08\xd3\x0f\x10\xd4\x0fJ\x06\x08\xd4\x0f\x10\xd5\x0fJ\x06\x08\xd5\x0f\x10\xd6\x0fJ\x06\x08\xd6\x0f\x10\xd7\x0fJ\x06\x08\xd7\x0f\x10\xd8\x0fJ\x06\x08\xd8\x0f\x10\xd9\x0fR\x17\x61pply_enable_remote_sshR\x0e\x61pply_lan_ipv4R\x12\x61pply_network_nameR\x17\x61pply_network_name_5ghzR\x16\x61pply_network_passwordR\x13\x61pply_wifi_securityR\x11\x65nable_remote_sshR\x08lan_ipv4R\x16last_remote_ssh_accessR\x0cnetwork_nameR\x11network_name_5ghzR\x10network_passwordR\rwifi_security\"\xda\x01\n\x13WeeklyBlockSchedule\x12T\n\x0c\x62lock_ranges\x18\x01 \x03(\x0b\x32\x31.SpaceX.API.Device.WeeklyBlockSchedule.BlockRangeR\x0b\x62lockRanges\x12\x19\n\x08group_id\x18\x02 \x01(\tR\x07groupId\x1aR\n\nBlockRange\x12#\n\rstart_minutes\x18\x01 \x01(\rR\x0cstartMinutes\x12\x1f\n\x0b\x65nd_minutes\x18\x02 \x01(\rR\nendMinutes\"\x81\x02\n\x0c\x43lientConfig\x12\x1b\n\tclient_id\x18\x01 \x01(\rR\x08\x63lientId\x12\x1f\n\x0bmac_address\x18\x02 \x01(\tR\nmacAddress\x12\x1d\n\ngiven_name\x18\x03 \x01(\tR\tgivenName\x12\\\n\x16weekly_block_schedules\x18\x05 \x03(\x0b\x32&.SpaceX.API.Device.WeeklyBlockScheduleR\x14weeklyBlockSchedules\x12\x19\n\x08group_id\x18\x06 \x01(\tR\x07groupIdJ\x04\x08\x04\x10\x05R\x15weekly_block_schedule\"L\n\nClientName\x12\x1f\n\x0bmac_address\x18\x01 \x01(\tR\nmacAddress\x12\x1d\n\ngiven_name\x18\x02 \x01(\tR\tgivenName\"\n\n\x08\x41uthOpen\"&\n\x08\x41uthWpa2\x12\x1a\n\x08password\x18\x01 \x01(\tR\x08password\"&\n\x08\x41uthWpa3\x12\x1a\n\x08password\x18\x01 \x01(\tR\x08password\"*\n\x0c\x41uthWpa2Wpa3\x12\x1a\n\x08password\x18\x01 \x01(\tR\x08password\"\xc7\x01\n\nAuthRadius\x12\x16\n\x06server\x18\x01 \x01(\tR\x06server\x12\x1f\n\tserver_ca\x18\x03 \x01(\tB\x02\x18\x01R\x08serverCa\x12)\n\x11server_ca_base_64\x18\x04 \x01(\tR\x0eserverCaBase64\x12\x1a\n\x08password\x18\x02 \x01(\tR\x08password\x12\x39\n\ttransport\x18\x05 \x01(\x0e\x32\x1b.SpaceX.API.Device.ProtocolR\ttransport\"\x12\n\x10NoTrafficControl\"\x9c\x02\n\x0e\x41\x63kSuppression\x12\x19\n\x08\x61\x63k_mark\x18\x01 \x01(\rR\x07\x61\x63kMark\x12+\n\x12htb_ack_queue_rate\x18\x02 \x01(\x02R\x0fhtbAckQueueRate\x12+\n\x12htb_ack_queue_ceil\x18\x03 \x01(\x02R\x0fhtbAckQueueCeil\x12\x30\n\x14\x63\x61ke_queue_bandwidth\x18\x04 \x01(\x02R\x12\x63\x61keQueueBandwidth\x12;\n\x1a\x63\x61ke_ack_filter_aggressive\x18\x05 \x01(\x08R\x17\x63\x61keAckFilterAggressive\x12&\n\x0f\x63\x61ke_manual_rtt\x18\x06 \x01(\x02R\rcakeManualRtt\"\x93\x02\n\rCakeRateLimit\x12\x1b\n\thost_mark\x18\x01 \x01(\rR\x08hostMark\x12\x1c\n\tbandwidth\x18\x02 \x01(\x02R\tbandwidth\x12g\n\x18priority_queue_parameter\x18\x03 \x01(\x0e\x32-.SpaceX.API.Device.CakePriorityQueueParameterR\x16priorityQueueParameter\x12?\n\nack_filter\x18\x04 \x01(\x0e\x32 .SpaceX.API.Device.CakeAckFilterR\tackFilter\x12\x1d\n\nmanual_rtt\x18\x06 \x01(\x02R\tmanualRtt*d\n\x08MeshAuth\x12\x15\n\x11MESH_AUTH_UNKNOWN\x10\x00\x12\x11\n\rMESH_AUTH_NEW\x10\x01\x12\x15\n\x11MESH_AUTH_TRUSTED\x10\x02\x12\x17\n\x13MESH_AUTH_UNTRUSTED\x10\x03*M\n\rCakeAckFilter\x12\x11\n\rNO_ACK_FILTER\x10\x00\x12\x0e\n\nACK_FILTER\x10\x01\x12\x19\n\x15\x41\x43K_FILTER_AGGRESSIVE\x10\x02*[\n\x1a\x43\x61kePriorityQueueParameter\x12\r\n\tDIFFSERV3\x10\x00\x12\r\n\tDIFFSERV4\x10\x01\x12\x0e\n\nPRECEDENCE\x10\x02\x12\x0f\n\x0b\x42\x45ST_EFFORT\x10\x03\x42\xd9\x01\n\x15\x63om.SpaceX.API.DeviceB\x0fWifiConfigProtoP\x01ZIgithub.com/Eitol/starlink-client/libs/golang/client/gen/spacex/api/device\xa2\x02\x03SAD\xaa\x02\x11SpaceX.API.Device\xca\x02\x11SpaceX\\API\\Device\xe2\x02\x1dSpaceX\\API\\Device\\GPBMetadata\xea\x02\x13SpaceX::API::Deviceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'spacex.api.device.wifi_config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.SpaceX.API.DeviceB\017WifiConfigProtoP\001ZIgithub.com/Eitol/starlink-client/libs/golang/client/gen/spacex/api/device\242\002\003SAD\252\002\021SpaceX.API.Device\312\002\021SpaceX\\API\\Device\342\002\035SpaceX\\API\\Device\\GPBMetadata\352\002\023SpaceX::API::Device'
  _globals['_WIFICONFIG_MESHCONFIGSENTRY']._loaded_options = None
  _globals['_WIFICONFIG_MESHCONFIGSENTRY']._serialized_options = b'8\001'
  _globals['_WIFICONFIG_MESHCONFIGSUPDATESENTRY']._loaded_options = None
  _globals['_WIFICONFIG_MESHCONFIGSUPDATESENTRY']._serialized_options = b'8\001'
  _globals['_WIFICONFIG'].fields_by_name['client_names']._loaded_options = None
  _globals['_WIFICONFIG'].fields_by_name['client_names']._serialized_options = b'\030\001'
  _globals['_WIFICONFIG'].fields_by_name['apply_client_names']._loaded_options = None
  _globals['_WIFICONFIG'].fields_by_name['apply_client_names']._serialized_options = b'\030\001'
  _globals['_WIFICONFIG'].fields_by_name['golden_bssid']._loaded_options = None
  _globals['_WIFICONFIG'].fields_by_name['golden_bssid']._serialized_options = b'\030\001'
  _globals['_WIFICONFIG'].fields_by_name['apply_golden_bssid']._loaded_options = None
  _globals['_WIFICONFIG'].fields_by_name['apply_golden_bssid']._serialized_options = b'\030\001'
  _globals['_WIFICONFIG'].fields_by_name['golden_iface_type']._loaded_options = None
  _globals['_WIFICONFIG'].fields_by_name['golden_iface_type']._serialized_options = b'\030\001'
  _globals['_WIFICONFIG'].fields_by_name['apply_golden_iface_type']._loaded_options = None
  _globals['_WIFICONFIG'].fields_by_name['apply_golden_iface_type']._serialized_options = b'\030\001'
  _globals['_AUTHRADIUS'].fields_by_name['server_ca']._loaded_options = None
  _globals['_AUTHRADIUS'].fields_by_name['server_ca']._serialized_options = b'\030\001'
  _globals['_MESHAUTH']._serialized_start=10497
  _globals['_MESHAUTH']._serialized_end=10597
  _globals['_CAKEACKFILTER']._serialized_start=10599
  _globals['_CAKEACKFILTER']._serialized_end=10676
  _globals['_CAKEPRIORITYQUEUEPARAMETER']._serialized_start=10678
  _globals['_CAKEPRIORITYQUEUEPARAMETER']._serialized_end=10769
  _globals['_MESHCONFIG']._serialized_start=159
  _globals['_MESHCONFIG']._serialized_end=506
  _globals['_WIFICONFIG']._serialized_start=509
  _globals['_WIFICONFIG']._serialized_end=9013
  _globals['_WIFICONFIG_MESHCONFIGSENTRY']._serialized_start=6428
  _globals['_WIFICONFIG_MESHCONFIGSENTRY']._serialized_end=6521
  _globals['_WIFICONFIG_MESHCONFIGSUPDATESENTRY']._serialized_start=6523
  _globals['_WIFICONFIG_MESHCONFIGSUPDATESENTRY']._serialized_end=6623
  _globals['_WIFICONFIG_BASICSERVICESET']._serialized_start=6626
  _globals['_WIFICONFIG_BASICSERVICESET']._serialized_end=7232
  _globals['_WIFICONFIG_NETWORK']._serialized_start=7235
  _globals['_WIFICONFIG_NETWORK']._serialized_end=7747
  _globals['_WIFICONFIG_SECURITY']._serialized_start=7749
  _globals['_WIFICONFIG_SECURITY']._serialized_end=7806
  _globals['_WIFICONFIG_BAND']._serialized_start=7808
  _globals['_WIFICONFIG_BAND']._serialized_end=7874
  _globals['_WIFICONFIG_WIRELESSMODE']._serialized_start=7877
  _globals['_WIFICONFIG_WIRELESSMODE']._serialized_end=8106
  _globals['_WIFICONFIG_HTBANDWIDTH']._serialized_start=8108
  _globals['_WIFICONFIG_HTBANDWIDTH']._serialized_end=8203
  _globals['_WIFICONFIG_VHTBANDWIDTH']._serialized_start=8206
  _globals['_WIFICONFIG_VHTBANDWIDTH']._serialized_end=8362
  _globals['_WEEKLYBLOCKSCHEDULE']._serialized_start=9016
  _globals['_WEEKLYBLOCKSCHEDULE']._serialized_end=9234
  _globals['_WEEKLYBLOCKSCHEDULE_BLOCKRANGE']._serialized_start=9152
  _globals['_WEEKLYBLOCKSCHEDULE_BLOCKRANGE']._serialized_end=9234
  _globals['_CLIENTCONFIG']._serialized_start=9237
  _globals['_CLIENTCONFIG']._serialized_end=9494
  _globals['_CLIENTNAME']._serialized_start=9496
  _globals['_CLIENTNAME']._serialized_end=9572
  _globals['_AUTHOPEN']._serialized_start=9574
  _globals['_AUTHOPEN']._serialized_end=9584
  _globals['_AUTHWPA2']._serialized_start=9586
  _globals['_AUTHWPA2']._serialized_end=9624
  _globals['_AUTHWPA3']._serialized_start=9626
  _globals['_AUTHWPA3']._serialized_end=9664
  _globals['_AUTHWPA2WPA3']._serialized_start=9666
  _globals['_AUTHWPA2WPA3']._serialized_end=9708
  _globals['_AUTHRADIUS']._serialized_start=9711
  _globals['_AUTHRADIUS']._serialized_end=9910
  _globals['_NOTRAFFICCONTROL']._serialized_start=9912
  _globals['_NOTRAFFICCONTROL']._serialized_end=9930
  _globals['_ACKSUPPRESSION']._serialized_start=9933
  _globals['_ACKSUPPRESSION']._serialized_end=10217
  _globals['_CAKERATELIMIT']._serialized_start=10220
  _globals['_CAKERATELIMIT']._serialized_end=10495
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DishConfig(_message.Message):
    __slots__ = ("snow_melt_mode", "apply_snow_melt_mode", "location_request_mode", "apply_location_request_mode", "level_dish_mode", "apply_level_dish_mode", "power_save_start_minutes", "apply_power_save_start_minutes", "power_save_duration_minutes", "apply_power_save_duration_minutes", "power_save_mode", "apply_power_save_mode", "swupdate_three_day_deferral_enabled", "apply_swupdate_three_day_deferral_enabled")
    class SnowMeltMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        AUTO: _ClassVar[DishConfig.SnowMeltMode]
        ALWAYS_ON: _ClassVar[DishConfig.SnowMeltMode]
        ALWAYS_OFF: _ClassVar[DishConfig.SnowMeltMode]
    AUTO: DishConfig.SnowMeltMode
    ALWAYS_ON: DishConfig.SnowMeltMode
    ALWAYS_OFF: DishConfig.SnowMeltMode
    class LocationRequestMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        NONE: _ClassVar[DishConfig.LocationRequestMode]
        LOCAL: _ClassVar[DishConfig.LocationRequestMode]
    NONE: DishConfig.LocationRequestMode
    LOCAL: DishConfig.LocationRequestMode
    class LevelDishMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        TILT_LIKE_NORMAL: _ClassVar[DishConfig.LevelDishMode]
        FORCE_LEVEL: _ClassVar[DishConfig.LevelDishMode]
    TILT_LIKE_NORMAL: DishConfig.LevelDishMode
    FORCE_LEVEL: DishConfig.LevelDishMode
    SNOW_MELT_MODE_FIELD_NUMBER: _ClassVar[int]
    APPLY_SNOW_MELT_MODE_FIELD_NUMBER: _ClassVar[int]
    LOCATION_REQUEST_MODE_FIELD_NUMBER: _ClassVar[int]
    APPLY_LOCATION_REQUEST_MODE_FIELD_NUMBER: _ClassVar[int]
    LEVEL_DISH_MODE_FIELD_NUMBER: _ClassVar[int]
    APPLY_LEVEL_DISH_MODE_FIELD_NUMBER: _ClassVar[int]
    POWER_SAVE_START_MINUTES_FIELD_NUMBER: _ClassVar[int]
    APPLY_POWER_SAVE_START_MINUTES_FIELD_NUMBER: _ClassVar[int]
    POWER_SAVE_DURATION_MINUTES_FIELD_NUMBER: _ClassVar[int]
    APPLY_POWER_SAVE_DURATION_MINUTES_FIELD_NUMBER: _ClassVar[int]
    POWER_SAVE_MODE_FIELD_NUMBER: _ClassVar[int]
    APPLY_POWER_SAVE_MODE_FIELD_NUMBER: _ClassVar[int]
    SWUPDATE_THREE_DAY_DEFERRAL_ENABLED_FIELD_NUMBER: _ClassVar[int]
    APPLY_SWUPDATE_THREE_DAY_DEFERRAL_ENABLED_FIELD_NUMBER: _ClassVar[int]
    snow_melt_mode: DishConfig.SnowMeltMode
    apply_snow_melt_mode: bool
    location_request_mode: DishConfig.LocationRequestMode
    apply_location_request_mode: bool
    level_dish_mode: DishConfig.LevelDishMode
    apply_level_dish_mode: bool
    power_save_start_minutes: int
    apply_power_save_start_minutes: bool
    power_save_duration_minutes: int
    apply_power_save_duration_minutes: bool
    power_save_mode: bool
    apply_power_save_mode: bool
    swupdate_three_day_deferral_enabled: bool
    apply_swupdate_three_day_deferral_enabled: bool
    def __init__(self, snow_melt_mode: _Optional[_Union[DishConfig.SnowMeltMode, str]] = ..., apply_snow_melt_mode: bool = ..., location_request_mode: _Optional[_Union[DishConfig.LocationRequestMode, str]] = ..., apply_location_request_mode: bool = ..., level_dish_mode: _Optional[_Union[DishConfig.LevelDishMode, str]] = ..., apply_level_dish_mode: bool = ..., power_save_start_minutes: _Optional[int] = ..., apply_power_save_start_minutes: bool = ..., power_save_duration_minutes: _Optional[int] = ..., apply_power_save_duration_minutes: bool = ..., power_save_mode: bool = ..., apply_power_save_mode: bool = ..., swupdate_three_day_deferral_enabled: bool = ..., apply_swupdate_three_day_deferral_enabled: bool = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class IfaceType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    IFACE_TYPE_UNKNOWN: _ClassVar[IfaceType]
    IFACE_TYPE_ETH: _ClassVar[IfaceType]
    IFACE_TYPE_RF_2GHZ: _ClassVar[IfaceType]
    IFACE_TYPE_RF_5GHZ: _ClassVar[IfaceType]
    IFACE_TYPE_RF_5GHZ_HIGH: _ClassVar[IfaceType]

class TxPowerLevel(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    TX_POWER_LEVEL_100: _ClassVar[TxPowerLevel]
    TX_POWER_LEVEL_80: _ClassVar[TxPowerLevel]
    TX_POWER_LEVEL_50: _ClassVar[TxPowerLevel]
    TX_POWER_LEVEL_25: _ClassVar[TxPowerLevel]
    TX_POWER_LEVEL_12: _ClassVar[TxPowerLevel]
    TX_POWER_LEVEL_6: _ClassVar[TxPowerLevel]

class PoeState(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    POE_STATE_DISABLED: _ClassVar[PoeState]
    POE_STATE_NEGOTIATING: _ClassVar[PoeState]
    POE_STATE_ON_RAMPUP: _ClassVar[PoeState]
    POE_STATE_ON: _ClassVar[PoeState]
    POE_STATE_WATER_DETECT_RAMPUP: _ClassVar[PoeState]
    POE_STATE_WATER_DETECT: _ClassVar[PoeState]

class PoeFault(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    POE_FAULT_FAST_OVERCURRENT: _ClassVar[PoeFault]
    POE_FAULT_SLOW_OVERCURRENT: _ClassVar[PoeFault]
    POE_FAULT_UNDERCURRENT: _ClassVar[PoeFault]
    POE_FAULT_OVERVOLTAGE: _ClassVar[PoeFault]
    POE_FAULT_UNDERVOLTAGE: _ClassVar[PoeFault]

class WifiMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    WIFI_MODE_DEFAULT: _ClassVar[WifiMode]
    A_ONLY: _ClassVar[WifiMode]
    B_ONLY: _ClassVar[WifiMode]
    G_ONLY: _ClassVar[WifiMode]
    N_ONLY: _ClassVar[WifiMode]
    B_G_MIXED: _ClassVar[WifiMode]
    A_N_MIXED: _ClassVar[WifiMode]
    G_N_MIXED: _ClassVar[WifiMode]
    B_G_N_MIXED: _ClassVar[WifiMode]
    A_AN_AC_MIXED: _ClassVar[WifiMode]
    AN_AC_MIXED: _ClassVar[WifiMode]
    B_G_N_AX_MIXED: _ClassVar[WifiMode]
    A_AN_AC_AX_MIXED: _ClassVar[WifiMode]
    A_N_AC_MIXED: _ClassVar[WifiMode]
    A_N_AC_AX_MIXED: _ClassVar[WifiMode]

class WifiSecurity(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    WIFI_SECURITY_UNKNOWN: _ClassVar[WifiSecurity]
    OPEN: _ClassVar[WifiSecurity]
    WPA2: _ClassVar[WifiSecurity]
    WPA3: _ClassVar[WifiSecurity]
    WPA2WPA3: _ClassVar[WifiSecurity]

class Protocol(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    TCP: _ClassVar[Protocol]
    UDP: _ClassVar[Protocol]
    TLS: _ClassVar[Protocol]
    DTLS: _ClassVar[Protocol]

class WifiSoftwareUpdateState(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    NOT_RUN: _ClassVar[WifiSoftwareUpdateState]
    GETTING_TARGET_VERSION: _ClassVar[WifiSoftwareUpdateState]
    DOWNLOADING_UPDATE_IMAGE: _ClassVar[WifiSoftwareUpdateState]
    FLASHING: _ClassVar[WifiSoftwareUpdateState]
    NO_UPDATE_REQUIRED: _ClassVar[WifiSoftwareUpdateState]
    REBOOT_PENDING: _ClassVar[WifiSoftwareUpdateState]
    GETTING_TARGET_VERSION_FAILED: _ClassVar[WifiSoftwareUpdateState]
    GETTING_TARGET_VERSION_EXHAUSTED: _ClassVar[WifiSoftwareUpdateState]
    NO_VALID_ARTIFACT: _ClassVar[WifiSoftwareUpdateState]
    ILLEGAL_ARTIFACT: _ClassVar[WifiSoftwareUpdateState]
    DOWNLOADING_UPDATE_IMAGE_FAILED: _ClassVar[WifiSoftwareUpdateState]
    DOWNLOADING_UPDATE_IMAGE_EXHAUSTED: _ClassVar[WifiSoftwareUpdateState]
    FLASHING_FAILED: _ClassVar[WifiSoftwareUpdateState]
IFACE_TYPE_UNKNOWN: IfaceType
IFACE_TYPE_ETH: IfaceType
IFACE_TYPE_RF_2GHZ: IfaceType
IFACE_TYPE_RF_5GHZ: IfaceType
IFACE_TYPE_RF_5GHZ_HIGH: IfaceType
TX_POWER_LEVEL_100: TxPowerLevel
TX_POWER_LEVEL_80: TxPowerLevel
TX_POWER_LEVEL_50: TxPowerLevel
TX_POWER_LEVEL_25: TxPowerLevel
TX_POWER_LEVEL_12: TxPowerLevel
TX_POWER_LEVEL_6: TxPowerLevel
POE_STATE_DISABLED: PoeState
POE_STATE_NEGOTIATING: PoeState
POE_STATE_ON_RAMPUP: PoeState
POE_STATE_ON: PoeState
POE_STATE_WATER_DETECT_RAMPUP: PoeState
POE_STATE_WATER_DETECT: PoeState
POE_FAULT_FAST_OVERCURRENT: PoeFault
POE_FAULT_SLOW_OVERCURRENT: PoeFault
POE_FAULT_UNDERCURRENT: PoeFault
POE_FAULT_OVERVOLTAGE: PoeFault
POE_FAULT_UNDERVOLTAGE: PoeFault
WIFI_MODE_DEFAULT: WifiMode
A_ONLY: WifiMode
B_ONLY: WifiMode
G_ONLY: WifiMode
N_ONLY: WifiMode
B_G_MIXED: WifiMode
A_N_MIXED: WifiMode
G_N_MIXED: WifiMode
B_G_N_MIXED: WifiMode
A_AN_AC_MIXED: WifiMode
AN_AC_MIXED: WifiMode
B_G_N_AX_MIXED: WifiMode
A_AN_AC_AX_MIXED: WifiMode
A_N_AC_MIXED: WifiMode
A_N_AC_AX_MIXED: WifiMode
WIFI_SECURITY_UNKNOWN: WifiSecurity
OPEN: WifiSecurity
WPA2: WifiSecurity
WPA3: WifiSecurity
WPA2WPA3: WifiSecurity
TCP: Protocol
UDP: Protocol
TLS: Protocol
DTLS: Protocol
NOT_RUN: WifiSoftwareUpdateState
GETTING_TARGET_VERSION: WifiSoftwareUpdateState
DOWNLOADING_UPDATE_IMAGE: WifiSoftwareUpdateState
FLASHING: WifiSoftwareUpdateState
NO_UPDATE_REQUIRED: WifiSoftwareUpdateState
REBOOT_PENDING: WifiSoftwareUpdateState
GETTING_TARGET_VERSION_FAILED: WifiSoftwareUpdateState
GETTING_TARGET_VERSION_EXHAUSTED: WifiSoftwareUpdateState
NO_VALID_ARTIFACT: WifiSoftwareUpdateState
ILLEGAL_ARTIFACT: WifiSoftwareUpdateState
DOWNLOADING_UPDATE_IMAGE_FAILED: WifiSoftwareUpdateState
DOWNLOADING_UPDATE_IMAGE_EXHAUSTED: WifiSoftwareUpdateState
FLASHING_FAILED: WifiSoftwareUpdateState

class InflatedBasicServiceSet(_message.Message):
    __slots__ = ("bssid", "ssid", "mac_lan", "iface_name", "iface_type", "channel", "preference")
    BSSID_FIELD_NUMBER: _ClassVar[int]
    SSID_FIELD_NUMBER: _ClassVar[int]
    MAC_LAN_FIELD_NUMBER: _ClassVar[int]
    IFACE_NAME_FIELD_NUMBER: _ClassVar[int]
    IFACE_TYPE_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_FIELD_NUMBER: _ClassVar[int]
    PREFERENCE_FIELD_NUMBER: _ClassVar[int]
    bssid: str
    ssid: str
    mac_lan: str
    iface_name: str
    iface_type: IfaceType
    channel: int
    preference: int
    def __init__(self, bssid: _Optional[str] = ..., ssid: _Optional[str] = ..., mac_lan: _Optional[str] = ..., iface_name: _Optional[str] = ..., iface_type: _Optional[_Union[IfaceType, str]] = ..., channel: _Optional[int] = ..., preference: _Optional[int] = ...) -> None: ...

class DhcpLease(_message.Message):
    __slots__ = ("ip_address", "mac_address", "hostname", "expires_time", "active", "client_id")
    IP_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    MAC_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    HOSTNAME_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_TIME_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    ip_address: str
    mac_address: str
    hostname: str
    expires_time: str
    active: bool
    client_id: int
    def __init__(self, ip_address: _Optional[str] = ..., mac_address: _Optional[str] = ..., hostname: _Optional[str] = ..., expires_time: _Optional[str] = ..., active: bool = ..., client_id: _Optional[int] = ...) -> None: ...

class DhcpServer(_message.Message):
    __slots__ = ("domain", "subnet", "leases")
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    SUBNET_FIELD_NUMBER: _ClassVar[int]
    LEASES_FIELD_NUMBER: _ClassVar[int]
    domain: str
    subnet: str
    leases: _containers.RepeatedCompositeFieldContainer[DhcpLease]
    def __init__(self, domain: _Optional[str] = ..., subnet: _Optional[str] = ..., leases: _Optional[_Iterable[_Union[DhcpLease, _Mapping]]] = ...) -> None: ...

class RadiusStatsMap(_message.Message):
    __slots__ = ("radius_stats",)
    class RadiusStatsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: RadiusStatsMap.RadiusStats
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[RadiusStatsMap.RadiusStats, _Mapping]] = ...) -> None: ...
    class RadiusStats(_message.Message):
        __slots__ = ("iface_name", "timeout_count", "access_request_count", "access_accept_count", "access_reject_count", "access_challenge_count", "accounting_request_count", "accounting_response_count")
        IFACE_NAME_FIELD_NUMBER: _ClassVar[int]
        TIMEOUT_COUNT_FIELD_NUMBER: _ClassVar[int]
        ACCESS_REQUEST_COUNT_FIELD_NUMBER: _ClassVar[int]
        ACCESS_ACCEPT_COUNT_FIELD_NUMBER: _ClassVar[int]
        ACCESS_REJECT_COUNT_FIELD_NUMBER: _ClassVar[int]
        ACCESS_CHALLENGE_COUNT_FIELD_NUMBER: _ClassVar[int]
        ACCOUNTING_REQUEST_COUNT_FIELD_NUMBER: _ClassVar[int]
        ACCOUNTING_RESPONSE_COUNT_FIELD_NUMBER: _ClassVar[int]
        iface_name: str
        timeout_count: int
        access_request_count: int
        access_accept_count: int
        access_reject_count: int
        access_challenge_count: int
        accounting_request_count: int
        accounting_response_count: int
        def __init__(self, iface_name: _Optional[str] = ..., timeout_count: _Optional[int] = ..., access_request_count: _Optional[int] = ..., access_accept_count: _Optional[int] = ..., access_reject_count: _Optional[int] = ..., access_challenge_count: _Optional[int] = ..., accounting_request_count: _Optional[int] = ..., accounting_response_count: _Optional[int] = ...) -> None: ...
    RADIUS_STATS_FIELD_NUMBER: _ClassVar[int]
    radius_stats: _containers.MessageMap[str, RadiusStatsMap.RadiusStats]
    def __init__(self, radius_stats: _Optional[_Mapping[str, RadiusStatsMap.RadiusStats]] = ...) -> None: ...

class PoeStats(_message.Message):
    __slots__ = ("poe_state", "poe_power", "poe_faults_fast_overcurrent", "poe_faults_slow_overcurrent", "poe_faults_overvoltage", "poe_faults_undervoltage")
    POE_STATE_FIELD_NUMBER: _ClassVar[int]
    POE_POWER_FIELD_NUMBER: _ClassVar[int]
    POE_FAULTS_FAST_OVERCURRENT_FIELD_NUMBER: _ClassVar[int]
    POE_FAULTS_SLOW_OVERCURRENT_FIELD_NUMBER: _ClassVar[int]
    POE_FAULTS_OVERVOLTAGE_FIELD_NUMBER: _ClassVar[int]
    POE_FAULTS_UNDERVOLTAGE_FIELD_NUMBER: _ClassVar[int]
    poe_state: PoeState
    poe_power: float
    poe_faults_fast_overcurrent: int
    poe_faults_slow_overcurrent: int
    poe_faults_overvoltage: int
    poe_faults_undervoltage: int
    def __init__(self, poe_state: _Optional[_Union[PoeState, str]] = ..., poe_power: _Optional[float] = ..., poe_faults_fast_overcurrent: _Optional[int] = ..., poe_faults_slow_overcurrent: _Optional[int] = ..., poe_faults_overvoltage: _Optional[int] = ..., poe_faults_undervoltage: _Optional[int] = ...) -> None: ...

class WifiSoftwareUpdateStats(_message.Message):
    __slots__ = ("state", "software_download_progress", "seconds_since_get_target_versions")
    STATE_FIELD_NUMBER: _ClassVar[int]
    SOFTWARE_DOWNLOAD_PROGRESS_FIELD_NUMBER: _ClassVar[int]
    SECONDS_SINCE_GET_TARGET_VERSIONS_FIELD_NUMBER: _ClassVar[int]
    state: WifiSoftwareUpdateState
    software_download_progress: float
    seconds_since_get_target_versions: float
    def __init__(self, state: _Optional[_Union[WifiSoftwareUpdateState, str]] = ..., software_download_progress: _Optional[float] = ..., seconds_since_get_target_versions: _Optional[float] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from spacex.api.device import wifi_pb2 as spacex_dot_api_dot_device_dot_wifi__pb2


class MeshStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.MeshStream = channel.stream_stream(
                '/SpaceX.API.Device.Mesh/MeshStream',
                request_serializer=spacex_dot_api_dot_device_dot_wifi__pb2.ToController.SerializeToString,
                response_deserializer=spacex_dot_api_dot_device_dot_wifi__pb2.FromController.FromString,
                _registered_method=True)


class MeshServicer(object):
    """Missing associated documentation comment in .proto file."""

    def MeshStream(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MeshServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'MeshStream': grpc.stream_stream_rpc_method_handler(
                    servicer.MeshStream,
                    request_deserializer=spacex_dot_api_dot_device_dot_wifi__pb2.ToController.FromString,
                    response_serializer=spacex_dot_api_dot_device_dot_wifi__pb2.FromController.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'SpaceX.API.Device.Mesh', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('SpaceX.API.Device.Mesh', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Mesh(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def MeshStream(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(
            request_iterator,
            target,
            '/SpaceX.API.Device.Mesh/MeshStream',
            spacex_dot_api_dot_device_dot_wifi__pb2.ToController.SerializeToString,
            spacex_dot_api_dot_device_dot_wifi__pb2.FromController.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



from spacex.api.device import dish_pb2 as _dish_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TransceiverModulatorState(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    MODSTATE_UNKNOWN: _ClassVar[TransceiverModulatorState]
    MODSTATE_ENABLED: _ClassVar[TransceiverModulatorState]
    MODSTATE_DISABLED: _ClassVar[TransceiverModulatorState]

class TransceiverTxRxState(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    TXRX_UNKNOWN: _ClassVar[TransceiverTxRxState]
    TXRX_ENABLED: _ClassVar[TransceiverTxRxState]
    TXRX_DISABLED: _ClassVar[TransceiverTxRxState]

class TransceiverTransmitBlankingState(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    TB_UNKNOWN: _ClassVar[TransceiverTransmitBlankingState]
    TB_ENABLED: _ClassVar[TransceiverTransmitBlankingState]
    TB_DISABLED: _ClassVar[TransceiverTransmitBlankingState]
MODSTATE_UNKNOWN: TransceiverModulatorState
MODSTATE_ENABLED: TransceiverModulatorState
MODSTATE_DISABLED: TransceiverModulatorState
TXRX_UNKNOWN: TransceiverTxRxState
TXRX_ENABLED: TransceiverTxRxState
TXRX_DISABLED: TransceiverTxRxState
TB_UNKNOWN: TransceiverTransmitBlankingState
TB_ENABLED: TransceiverTransmitBlankingState
TB_DISABLED: TransceiverTransmitBlankingState

class TransceiverIFLoopbackTestRequest(_message.Message):
    __slots__ = ("enable_if_loopback",)
    ENABLE_IF_LOOPBACK_FIELD_NUMBER: _ClassVar[int]
    enable_if_loopback: bool
    def __init__(self, enable_if_loopback: bool = ...) -> None: ...

class TransceiverIFLoopbackTestResponse(_message.Message):
    __slots__ = ("ber_loopback_test", "snr_loopback_test", "rssi_loopback_test", "pll_lock")
    BER_LOOPBACK_TEST_FIELD_NUMBER: _ClassVar[int]
    SNR_LOOPBACK_TEST_FIELD_NUMBER: _ClassVar[int]
    RSSI_LOOPBACK_TEST_FIELD_NUMBER: _ClassVar[int]
    PLL_LOCK_FIELD_NUMBER: _ClassVar[int]
    ber_loopback_test: float
    snr_loopback_test: float
    rssi_loopback_test: float
    pll_lock: bool
    def __init__(self, ber_loopback_test: _Optional[float] = ..., snr_loopback_test: _Optional[float] = ..., rssi_loopback_test: _Optional[float] = ..., pll_lock: bool = ...) -> None: ...

class TransceiverGetStatusRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class TransceiverGetStatusResponse(_message.Message):
    __slots__ = ("mod_state", "demod_state", "tx_state", "rx_state", "state", "faults", "transmit_blanking_state", "modem_asic_temp", "tx_if_temp")
    MOD_STATE_FIELD_NUMBER: _ClassVar[int]
    DEMOD_STATE_FIELD_NUMBER: _ClassVar[int]
    TX_STATE_FIELD_NUMBER: _ClassVar[int]
    RX_STATE_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    FAULTS_FIELD_NUMBER: _ClassVar[int]
    TRANSMIT_BLANKING_STATE_FIELD_NUMBER: _ClassVar[int]
    MODEM_ASIC_TEMP_FIELD_NUMBER: _ClassVar[int]
    TX_IF_TEMP_FIELD_NUMBER: _ClassVar[int]
    mod_state: TransceiverModulatorState
    demod_state: TransceiverModulatorState
    tx_state: TransceiverTxRxState
    rx_state: TransceiverTxRxState
    state: _dish_pb2.DishState
    faults: TransceiverFaults
    transmit_blanking_state: TransceiverTransmitBlankingState
    modem_asic_temp: float
    tx_if_temp: float
    def __init__(self, mod_state: _Optional[_Union[TransceiverModulatorState, str]] = ..., demod_state: _Optional[_Union[TransceiverModulatorState, str]] = ..., tx_state: _Optional[_Union[TransceiverTxRxState, str]] = ..., rx_state: _Optional[_Union[TransceiverTxRxState, str]] = ..., state: _Optional[_Union[_dish_pb2.DishState, str]] = ..., faults: _Optional[_Union[TransceiverFaults, _Mapping]] = ..., transmit_blanking_state: _Optional[_Union[TransceiverTransmitBlankingState, str]] = ..., modem_asic_temp: _Optional[float] = ..., tx_if_temp: _Optional[float] = ...) -> None: ...

class TransceiverFaults(_message.Message):
    __slots__ = ("over_temp_modem_asic_fault", "over_temp_pcba_fault", "dc_voltage_fault")
    OVER_TEMP_MODEM_ASIC_FAULT_FIELD_NUMBER: _ClassVar[int]
    OVER_TEMP_PCBA_FAULT_FIELD_NUMBER: _ClassVar[int]
    DC_VOLTAGE_FAULT_FIELD_NUMBER: _ClassVar[int]
    over_temp_modem_asic_fault: bool
    over_temp_pcba_fault: bool
    dc_voltage_fault: bool
    def __init__(self, over_temp_modem_asic_fault: bool = ..., over_temp_pcba_fault: bool = ..., dc_voltage_fault: bool = ...) -> None: ...

class TransceiverGetTelemetryRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class TransceiverGetTelemetryResponse(_message.Message):
    __slots__ = ("antenna_pointing_mode", "antenna_pitch", "antenna_roll", "antenna_rx_theta", "antenna_true_heading", "rx_channel", "current_cell_id", "seconds_until_slot_end", "wb_rssi_peak_mag_db", "pop_ping_drop_rate", "snr_db", "l1_snr_avg_db", "l1_snr_min_db", "l1_snr_max_db", "lmac_satellite_id", "target_satellite_id", "grant_mcs", "grant_symbols_avg", "ded_grant", "mobility_proactive_slot_change", "mobility_reactive_slot_change", "rfp_total_syn_failed", "num_out_of_seq", "num_ulmap_drop", "current_seconds_of_schedule", "send_label_switch_to_ground_failed_calls", "ema_velocity_x", "ema_velocity_y", "ema_velocity_z", "ce_rssi_db")
    ANTENNA_POINTING_MODE_FIELD_NUMBER: _ClassVar[int]
    ANTENNA_PITCH_FIELD_NUMBER: _ClassVar[int]
    ANTENNA_ROLL_FIELD_NUMBER: _ClassVar[int]
    ANTENNA_RX_THETA_FIELD_NUMBER: _ClassVar[int]
    ANTENNA_TRUE_HEADING_FIELD_NUMBER: _ClassVar[int]
    RX_CHANNEL_FIELD_NUMBER: _ClassVar[int]
    CURRENT_CELL_ID_FIELD_NUMBER: _ClassVar[int]
    SECONDS_UNTIL_SLOT_END_FIELD_NUMBER: _ClassVar[int]
    WB_RSSI_PEAK_MAG_DB_FIELD_NUMBER: _ClassVar[int]
    POP_PING_DROP_RATE_FIELD_NUMBER: _ClassVar[int]
    SNR_DB_FIELD_NUMBER: _ClassVar[int]
    L1_SNR_AVG_DB_FIELD_NUMBER: _ClassVar[int]
    L1_SNR_MIN_DB_FIELD_NUMBER: _ClassVar[int]
    L1_SNR_MAX_DB_FIELD_NUMBER: _ClassVar[int]
    LMAC_SATELLITE_ID_FIELD_NUMBER: _ClassVar[int]
    TARGET_SATELLITE_ID_FIELD_NUMBER: _ClassVar[int]
    GRANT_MCS_FIELD_NUMBER: _ClassVar[int]
    GRANT_SYMBOLS_AVG_FIELD_NUMBER: _ClassVar[int]
    DED_GRANT_FIELD_NUMBER: _ClassVar[int]
    MOBILITY_PROACTIVE_SLOT_CHANGE_FIELD_NUMBER: _ClassVar[int]
    MOBILITY_REACTIVE_SLOT_CHANGE_FIELD_NUMBER: _ClassVar[int]
    RFP_TOTAL_SYN_FAILED_FIELD_NUMBER: _ClassVar[int]
    NUM_OUT_OF_SEQ_FIELD_NUMBER: _ClassVar[int]
    NUM_ULMAP_DROP_FIELD_NUMBER: _ClassVar[int]
    CURRENT_SECONDS_OF_SCHEDULE_FIELD_NUMBER: _ClassVar[int]
    SEND_LABEL_SWITCH_TO_GROUND_FAILED_CALLS_FIELD_NUMBER: _ClassVar[int]
    EMA_VELOCITY_X_FIELD_NUMBER: _ClassVar[int]
    EMA_VELOCITY_Y_FIELD_NUMBER: _ClassVar[int]
    EMA_VELOCITY_Z_FIELD_NUMBER: _ClassVar[int]
    CE_RSSI_DB_FIELD_NUMBER: _ClassVar[int]
    antenna_pointing_mode: int
    antenna_pitch: float
    antenna_roll: float
    antenna_rx_theta: float
    antenna_true_heading: float
    rx_channel: int
    current_cell_id: int
    seconds_until_slot_end: float
    wb_rssi_peak_mag_db: float
    pop_ping_drop_rate: float
    snr_db: float
    l1_snr_avg_db: float
    l1_snr_min_db: float
    l1_snr_max_db: float
    lmac_satellite_id: int
    target_satellite_id: int
    grant_mcs: int
    grant_symbols_avg: float
    ded_grant: int
    mobility_proactive_slot_change: int
    mobility_reactive_slot_change: int
    rfp_total_syn_failed: int
    num_out_of_seq: int
    num_ulmap_drop: int
    current_seconds_of_schedule: float
    send_label_switch_to_ground_failed_calls: int
    ema_velocity_x: float
    ema_velocity_y: float
    ema_velocity_z: float
    ce_rssi_db: float
    def __init__(self, antenna_pointing_mode: _Optional[int] = ..., antenna_pitch: _Optional[float] = ..., antenna_roll: _Optional[float] = ..., antenna_rx_theta: _Optional[float] = ..., antenna_true_heading: _Optional[float] = ..., rx_channel: _Optional[int] = ..., current_cell_id: _Optional[int] = ..., seconds_until_slot_end: _Optional[float] = ..., wb_rssi_peak_mag_db: _Optional[float] = ..., pop_ping_drop_rate: _Optional[float] = ..., snr_db: _Optional[float] = ..., l1_snr_avg_db: _Optional[float] = ..., l1_snr_min_db: _Optional[float] = ..., l1_snr_max_db: _Optional[float] = ..., lmac_satellite_id: _Optional[int] = ..., target_satellite_id: _Optional[int] = ..., grant_mcs: _Optional[int] = ..., grant_symbols_avg: _Optional[float] = ..., ded_grant: _Optional[int] = ..., mobility_proactive_slot_change: _Optional[int] = ..., mobility_reactive_slot_change: _Optional[int] = ..., rfp_total_syn_failed: _Optional[int] = ..., num_out_of_seq: _Optional[int] = ..., num_ulmap_drop: _Optional[int] = ..., current_seconds_of_schedule: _Optional[float] = ..., send_label_switch_to_ground_failed_calls: _Optional[int] = ..., ema_velocity_x: _Optional[float] = ..., ema_velocity_y: _Optional[float] = ..., ema_velocity_z: _Optional[float] = ..., ce_rssi_db: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: spacex/api/device/transceiver.proto
# Protobuf Python Version: 5.29.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    3,
    '',
    'spacex/api/device/transceiver.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from spacex.api.device import dish_pb2 as spacex_dot_api_dot_device_dot_dish__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#spacex/api/device/transceiver.proto\x12\x11SpaceX.API.Device\x1a\x1cspacex/api/device/dish.proto\"P\n TransceiverIFLoopbackTestRequest\x12,\n\x12\x65nable_if_loopback\x18\x01 \x01(\x08R\x10\x65nableIfLoopback\"\xc4\x01\n!TransceiverIFLoopbackTestResponse\x12*\n\x11\x62\x65r_loopback_test\x18\x01 \x01(\x02R\x0f\x62\x65rLoopbackTest\x12*\n\x11snr_loopback_test\x18\x02 \x01(\x02R\x0fsnrLoopbackTest\x12,\n\x12rssi_loopback_test\x18\x03 \x01(\x02R\x10rssiLoopbackTest\x12\x19\n\x08pll_lock\x18\x04 \x01(\x08R\x07pllLock\"\x1d\n\x1bTransceiverGetStatusRequest\"\xea\x04\n\x1cTransceiverGetStatusResponse\x12I\n\tmod_state\x18\x01 \x01(\x0e\x32,.SpaceX.API.Device.TransceiverModulatorStateR\x08modState\x12M\n\x0b\x64\x65mod_state\x18\x02 \x01(\x0e\x32,.SpaceX.API.Device.TransceiverModulatorStateR\ndemodState\x12\x42\n\x08tx_state\x18\x03 \x01(\x0e\x32\'.SpaceX.API.Device.TransceiverTxRxStateR\x07txState\x12\x42\n\x08rx_state\x18\x04 \x01(\x0e\x32\'.SpaceX.API.Device.TransceiverTxRxStateR\x07rxState\x12\x33\n\x05state\x18\xee\x07 \x01(\x0e\x32\x1c.SpaceX.API.Device.DishStateR\x05state\x12=\n\x06\x66\x61ults\x18\xef\x07 \x01(\x0b\x32$.SpaceX.API.Device.TransceiverFaultsR\x06\x66\x61ults\x12l\n\x17transmit_blanking_state\x18\xf0\x07 \x01(\x0e\x32\x33.SpaceX.API.Device.TransceiverTransmitBlankingStateR\x15transmitBlankingState\x12\'\n\x0fmodem_asic_temp\x18\xf1\x07 \x01(\x02R\rmodemAsicTemp\x12\x1d\n\ntx_if_temp\x18\xf2\x07 \x01(\x02R\x08txIfTemp\"\xaa\x01\n\x11TransceiverFaults\x12:\n\x1aover_temp_modem_asic_fault\x18\x01 \x01(\x08R\x16overTempModemAsicFault\x12/\n\x14over_temp_pcba_fault\x18\x02 \x01(\x08R\x11overTempPcbaFault\x12(\n\x10\x64\x63_voltage_fault\x18\x03 \x01(\x08R\x0e\x64\x63VoltageFault\" \n\x1eTransceiverGetTelemetryRequest\"\xd9\n\n\x1fTransceiverGetTelemetryResponse\x12\x33\n\x15\x61ntenna_pointing_mode\x18\xe9\x07 \x01(\rR\x13\x61ntennaPointingMode\x12$\n\rantenna_pitch\x18\xea\x07 \x01(\x02R\x0c\x61ntennaPitch\x12\"\n\x0c\x61ntenna_roll\x18\xeb\x07 \x01(\x02R\x0b\x61ntennaRoll\x12)\n\x10\x61ntenna_rx_theta\x18\xec\x07 \x01(\x02R\x0e\x61ntennaRxTheta\x12\x31\n\x14\x61ntenna_true_heading\x18\xed\x07 \x01(\x02R\x12\x61ntennaTrueHeading\x12\x1e\n\nrx_channel\x18\xee\x07 \x01(\rR\trxChannel\x12\'\n\x0f\x63urrent_cell_id\x18\xef\x07 \x01(\rR\rcurrentCellId\x12\x34\n\x16seconds_until_slot_end\x18\xf0\x07 \x01(\x02R\x13secondsUntilSlotEnd\x12-\n\x13wb_rssi_peak_mag_db\x18\xf1\x07 \x01(\x02R\x0fwbRssiPeakMagDb\x12,\n\x12pop_ping_drop_rate\x18\xf2\x07 \x01(\x02R\x0fpopPingDropRate\x12\x16\n\x06snr_db\x18\xf3\x07 \x01(\x02R\x05snrDb\x12\"\n\rl1_snr_avg_db\x18\xf4\x07 \x01(\x02R\nl1SnrAvgDb\x12\"\n\rl1_snr_min_db\x18\xf5\x07 \x01(\x02R\nl1SnrMinDb\x12\"\n\rl1_snr_max_db\x18\xf6\x07 \x01(\x02R\nl1SnrMaxDb\x12+\n\x11lmac_satellite_id\x18\xf7\x07 \x01(\rR\x0flmacSatelliteId\x12/\n\x13target_satellite_id\x18\xf8\x07 \x01(\rR\x11targetSatelliteId\x12\x1c\n\tgrant_mcs\x18\xf9\x07 \x01(\rR\x08grantMcs\x12+\n\x11grant_symbols_avg\x18\xfa\x07 \x01(\x02R\x0fgrantSymbolsAvg\x12\x1c\n\tded_grant\x18\xfb\x07 \x01(\rR\x08\x64\x65\x64Grant\x12\x44\n\x1emobility_proactive_slot_change\x18\xfc\x07 \x01(\rR\x1bmobilityProactiveSlotChange\x12\x42\n\x1dmobility_reactive_slot_change\x18\xfd\x07 \x01(\rR\x1amobilityReactiveSlotChange\x12\x30\n\x14rfp_total_syn_failed\x18\xfe\x07 \x01(\rR\x11rfpTotalSynFailed\x12$\n\x0enum_out_of_seq\x18\xff\x07 \x01(\rR\x0bnumOutOfSeq\x12%\n\x0enum_ulmap_drop\x18\x80\x08 \x01(\rR\x0cnumUlmapDrop\x12>\n\x1b\x63urrent_seconds_of_schedule\x18\x81\x08 \x01(\x02R\x18\x63urrentSecondsOfSchedule\x12U\n(send_label_switch_to_ground_failed_calls\x18\x82\x08 \x01(\rR\"sendLabelSwitchToGroundFailedCalls\x12%\n\x0e\x65ma_velocity_x\x18\x83\x08 \x01(\x01R\x0c\x65maVelocityX\x12%\n\x0e\x65ma_velocity_y\x18\x84\x08 \x01(\x01R\x0c\x65maVelocityY\x12%\n\x0e\x65ma_velocity_z\x18\x85\x08 \x01(\x01R\x0c\x65maVelocityZ\x12\x1d\n\nce_rssi_db\x18\x86\x08 \x01(\x02R\x08\x63\x65RssiDb*^\n\x19TransceiverModulatorState\x12\x14\n\x10MODSTATE_UNKNOWN\x10\x00\x12\x14\n\x10MODSTATE_ENABLED\x10\x01\x12\x15\n\x11MODSTATE_DISABLED\x10\x02*M\n\x14TransceiverTxRxState\x12\x10\n\x0cTXRX_UNKNOWN\x10\x00\x12\x10\n\x0cTXRX_ENABLED\x10\x01\x12\x11\n\rTXRX_DISABLED\x10\x02*S\n TransceiverTransmitBlankingState\x12\x0e\n\nTB_UNKNOWN\x10\x00\x12\x0e\n\nTB_ENABLED\x10\x01\x12\x0f\n\x0bTB_DISABLED\x10\x02\x42\xda\x01\n\x15\x63om.SpaceX.API.DeviceB\x10TransceiverProtoP\x01ZIgithub.com/Eitol/starlink-client/libs/golang/client/gen/spacex/api/device\xa2\x02\x03SAD\xaa\x02\x11SpaceX.API.Device\xca\x02\x11SpaceX\\API\\Device\xe2\x02\x1dSpaceX\\API\\Device\\GPBMetadata\xea\x02\x13SpaceX::API::Deviceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'spacex.api.device.transceiver_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.SpaceX.API.DeviceB\020TransceiverProtoP\001ZIgithub.com/Eitol/starlink-client/libs/golang/client/gen/spacex/api/device\242\002\003SAD\252\002\021SpaceX.API.Device\312\002\021SpaceX\\API\\Device\342\002\035SpaceX\\API\\Device\\GPBMetadata\352\002\023SpaceX::API::Device'
  _globals['_TRANSCEIVERMODULATORSTATE']._serialized_start=2600
  _globals['_TRANSCEIVERMODULATORSTATE']._serialized_end=2694
  _globals['_TRANSCEIVERTXRXSTATE']._serialized_start=2696
  _globals['_TRANSCEIVERTXRXSTATE']._serialized_end=2773
  _globals['_TRANSCEIVERTRANSMITBLANKINGSTATE']._serialized_start=2775
  _globals['_TRANSCEIVERTRANSMITBLANKINGSTATE']._serialized_end=2858
  _globals['_TRANSCEIVERIFLOOPBACKTESTREQUEST']._serialized_start=88
  _globals['_TRANSCEIVERIFLOOPBACKTESTREQUEST']._serialized_end=168
  _globals['_TRANSCEIVERIFLOOPBACKTESTRESPONSE']._serialized_start=171
  _globals['_TRANSCEIVERIFLOOPBACKTESTRESPONSE']._serialized_end=367
  _globals['_TRANSCEIVERGETSTATUSREQUEST']._serialized_start=369
  _globals['_TRANSCEIVERGETSTATUSREQUEST']._serialized_end=398
  _globals['_TRANSCEIVERGETSTATUSRESPONSE']._serialized_start=401
  _globals['_TRANSCEIVERGETSTATUSRESPONSE']._serialized_end=1019
  _globals['_TRANSCEIVERFAULTS']._serialized_start=1022
  _globals['_TRANSCEIVERFAULTS']._serialized_end=1192
  _globals['_TRANSCEIVERGETTELEMETRYREQUEST']._serialized_start=1194
  _globals['_TRANSCEIVERGETTELEMETRYREQUEST']._serialized_end=1226
  _globals['_TRANSCEIVERGETTELEMETRYRESPONSE']._serialized_start=1229
  _globals['_TRANSCEIVERGETTELEMETRYRESPONSE']._serialized_end=2598
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: spacex/api/common/status/status.proto
# Protobuf Python Version: 5.29.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    3,
    '',
    'spacex/api/common/status/status.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%spacex/api/common/status/status.proto\x12\x11SpaceX.API.Status\"6\n\x06Status\x12\x12\n\x04\x63ode\x18\x01 \x01(\x05R\x04\x63ode\x12\x18\n\x07message\x18\x02 \x01(\tR\x07messageB\xdc\x01\n\x15\x63om.SpaceX.API.StatusB\x0bStatusProtoP\x01ZPgithub.com/Eitol/starlink-client/libs/golang/client/gen/spacex/api/common/status\xa2\x02\x03SAS\xaa\x02\x11SpaceX.API.Status\xca\x02\x11SpaceX\\API\\Status\xe2\x02\x1dSpaceX\\API\\Status\\GPBMetadata\xea\x02\x13SpaceX::API::Statusb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'spacex.api.common.status.status_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.SpaceX.API.StatusB\013StatusProtoP\001ZPgithub.com/Eitol/starlink-client/libs/golang/client/gen/spacex/api/common/status\242\002\003SAS\252\002\021SpaceX.API.Status\312\002\021SpaceX\\API\\Status\342\002\035SpaceX\\API\\Status\\GPBMetadata\352\002\023SpaceX::API::Status'
  _globals['_STATUS']._serialized_start=60
  _globals['_STATUS']._serialized_end=114
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: spacex/api/device/common.proto
# Protobuf Python Version: 5.29.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    3,
    '',
    'spacex/api/device/common.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1espacex/api/device/common.proto\x12\x11SpaceX.API.Device\"\xc9\x04\n\nDeviceInfo\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12)\n\x10hardware_version\x18\x02 \x01(\tR\x0fhardwareVersion\x12\x1b\n\tboard_rev\x18\x0e \x01(\x05R\x08\x62oardRev\x12)\n\x10software_version\x18\x03 \x01(\tR\x0fsoftwareVersion\x12\x31\n\x14manufactured_version\x18\x0b \x01(\tR\x13manufacturedVersion\x12+\n\x11generation_number\x18\x0c \x01(\x03R\x10generationNumber\x12!\n\x0c\x63ountry_code\x18\x04 \x01(\tR\x0b\x63ountryCode\x12 \n\x0cutc_offset_s\x18\x05 \x01(\x05R\nutcOffsetS\x12:\n\x19software_partitions_equal\x18\x06 \x01(\x08R\x17softwarePartitionsEqual\x12\x15\n\x06is_dev\x18\x07 \x01(\x08R\x05isDev\x12\x1c\n\tbootcount\x18\x08 \x01(\x05R\tbootcount\x12\x32\n\x15\x61nti_rollback_version\x18\t \x01(\x05R\x13\x61ntiRollbackVersion\x12\x17\n\x07is_hitl\x18\n \x01(\x08R\x06isHitl\x12\x30\n\x04\x62oot\x18\xe9\x07 \x01(\x0b\x32\x1b.SpaceX.API.Device.BootInfoR\x04\x62oot\x12#\n\rdish_cohoused\x18\r \x01(\x08R\x0c\x64ishCohoused\"(\n\x0b\x44\x65viceState\x12\x19\n\x08uptime_s\x18\x01 \x01(\x04R\x07uptimeS\">\n\nSignedData\x12\x12\n\x04\x64\x61ta\x18\x01 \x01(\x0cR\x04\x64\x61ta\x12\x1c\n\tsignature\x18\x02 \x01(\x0cR\tsignature\"\x12\n\x10GetNextIdRequest\">\n\x11GetNextIdResponse\x12\x0e\n\x02id\x18\x01 \x01(\x04R\x02id\x12\x19\n\x08\x65poch_id\x18\x02 \x01(\x04R\x07\x65pochId\"\xfb\x03\n\x08\x42ootInfo\x12V\n\x0f\x63ount_by_reason\x18\x01 \x03(\x0b\x32..SpaceX.API.Device.BootInfo.CountByReasonEntryR\rcountByReason\x12\x66\n\x15\x63ount_by_reason_delta\x18\x04 \x03(\x0b\x32\x33.SpaceX.API.Device.BootInfo.CountByReasonDeltaEntryR\x12\x63ountByReasonDelta\x12>\n\x0blast_reason\x18\x02 \x01(\x0e\x32\x1d.SpaceX.API.Device.BootReasonR\nlastReason\x12\x1d\n\nlast_count\x18\x03 \x01(\x05R\tlastCount\x12\x1d\n\ncrash_boot\x18\x05 \x01(\x08R\tcrashBoot\x12(\n\x10\x63rash_boot_count\x18\x06 \x01(\x05R\x0e\x63rashBootCount\x1a@\n\x12\x43ountByReasonEntry\x12\x10\n\x03key\x18\x01 \x01(\x05R\x03key\x12\x14\n\x05value\x18\x02 \x01(\x05R\x05value:\x02\x38\x01\x1a\x45\n\x17\x43ountByReasonDeltaEntry\x12\x10\n\x03key\x18\x01 \x01(\x05R\x03key\x12\x14\n\x05value\x18\x02 \x01(\x05R\x05value:\x02\x38\x01\"\\\n\nPingTarget\x12\x18\n\x07service\x18\x01 \x01(\tR\x07service\x12\x1a\n\x08location\x18\x02 \x01(\tR\x08location\x12\x18\n\x07\x61\x64\x64ress\x18\x03 \x01(\tR\x07\x61\x64\x64ress\"}\n\nPingResult\x12\x35\n\x06target\x18\x03 \x01(\x0b\x32\x1d.SpaceX.API.Device.PingTargetR\x06target\x12\x1a\n\x08\x64ropRate\x18\x01 \x01(\x02R\x08\x64ropRate\x12\x1c\n\tlatencyMs\x18\x02 \x01(\x02R\tlatencyMs\"Z\n\x10\x42ondingChallenge\x12\x17\n\x07\x64ish_id\x18\x01 \x01(\tR\x06\x64ishId\x12\x17\n\x07wifi_id\x18\x02 \x01(\tR\x06wifiId\x12\x14\n\x05nonce\x18\x03 \x01(\x0cR\x05nonce\"R\n\x13\x41uthenticateRequest\x12;\n\tchallenge\x18\x01 \x01(\x0b\x32\x1d.SpaceX.API.Device.SignedDataR\tchallenge\"^\n\x11\x43hallengeResponse\x12\x1c\n\tsignature\x18\x01 \x01(\x0cR\tsignature\x12+\n\x11\x63\x65rtificate_chain\x18\x02 \x01(\x0cR\x10\x63\x65rtificateChain\"\xad\x05\n\x10NetworkInterface\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x0e\n\x02up\x18\x04 \x01(\x08R\x02up\x12\x1f\n\x0bmac_address\x18\x05 \x01(\tR\nmacAddress\x12%\n\x0eipv4_addresses\x18\x06 \x03(\tR\ripv4Addresses\x12%\n\x0eipv6_addresses\x18\x07 \x03(\tR\ripv6Addresses\x12\x46\n\x08rx_stats\x18\x02 \x01(\x0b\x32+.SpaceX.API.Device.NetworkInterface.RxStatsR\x07rxStats\x12\x46\n\x08tx_stats\x18\x03 \x01(\x0b\x32+.SpaceX.API.Device.NetworkInterface.TxStatsR\x07txStats\x12J\n\x08\x65thernet\x18\xe8\x07 \x01(\x0b\x32+.SpaceX.API.Device.EthernetNetworkInterfaceH\x00R\x08\x65thernet\x12>\n\x04wifi\x18\xe9\x07 \x01(\x0b\x32\'.SpaceX.API.Device.WifiNetworkInterfaceH\x00R\x04wifi\x12\x44\n\x06\x62ridge\x18\xea\x07 \x01(\x0b\x32).SpaceX.API.Device.BridgeNetworkInterfaceH\x00R\x06\x62ridge\x1a\\\n\x07RxStats\x12\x14\n\x05\x62ytes\x18\x01 \x01(\x04R\x05\x62ytes\x12\x18\n\x07packets\x18\x02 \x01(\x04R\x07packets\x12!\n\x0c\x66rame_errors\x18\x03 \x01(\x04R\x0b\x66rameErrors\x1a\x39\n\x07TxStats\x12\x14\n\x05\x62ytes\x18\x01 \x01(\x04R\x05\x62ytes\x12\x18\n\x07packets\x18\x02 \x01(\x04R\x07packetsB\x0b\n\tinterface\"\x84\x02\n\x18\x45thernetNetworkInterface\x12#\n\rlink_detected\x18\x01 \x01(\x08R\x0clinkDetected\x12\x1d\n\nspeed_mbps\x18\x02 \x01(\rR\tspeedMbps\x12-\n\x12\x61utonegotiation_on\x18\x03 \x01(\x08R\x11\x61utonegotiationOn\x12J\n\x06\x64uplex\x18\x04 \x01(\x0e\x32\x32.SpaceX.API.Device.EthernetNetworkInterface.DuplexR\x06\x64uplex\")\n\x06\x44uplex\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04HALF\x10\x01\x12\x08\n\x04\x46ULL\x10\x02\"\xc9\x04\n\x14WifiNetworkInterface\x12o\n\x15invalid_packet_counts\x18\x02 \x01(\x0b\x32;.SpaceX.API.Device.WifiNetworkInterface.InvalidPacketCountsR\x13invalidPacketCounts\x12\x18\n\x07\x63hannel\x18\x03 \x01(\rR\x07\x63hannel\x12%\n\x0emissed_beacons\x18\x08 \x01(\rR\rmissedBeacons\x12!\n\x0clink_quality\x18\x04 \x01(\x01R\x0blinkQuality\x12!\n\x0csignal_level\x18\x05 \x01(\x01R\x0bsignalLevel\x12\x1f\n\x0bnoise_level\x18\x06 \x01(\x01R\nnoiseLevel\x1a\xe4\x01\n\x13InvalidPacketCounts\x12&\n\x0frx_invalid_nwid\x18\x01 \x01(\rR\rrxInvalidNwid\x12(\n\x10rx_invalid_crypt\x18\x02 \x01(\rR\x0erxInvalidCrypt\x12&\n\x0frx_invalid_frag\x18\x03 \x01(\rR\rrxInvalidFrag\x12\x30\n\x14tx_excessive_retries\x18\x04 \x01(\rR\x12txExcessiveRetries\x12!\n\x0cinvalid_misc\x18\x05 \x01(\rR\x0binvalidMiscJ\x04\x08\x01\x10\x02J\x04\x08\x07\x10\x08J\x04\x08\t\x10\nR\x0ethermal_statusR\x0f\x61ntennae_status\";\n\x16\x42ridgeNetworkInterface\x12!\n\x0cmember_names\x18\x01 \x03(\tR\x0bmemberNames\"C\n\x0bLLAPosition\x12\x10\n\x03lat\x18\x01 \x01(\x01R\x03lat\x12\x10\n\x03lon\x18\x02 \x01(\x01R\x03lon\x12\x10\n\x03\x61lt\x18\x03 \x01(\x01R\x03\x61lt\"8\n\x0c\x45\x43\x45\x46Position\x12\x0c\n\x01x\x18\x01 \x01(\x01R\x01x\x12\x0c\n\x01y\x18\x02 \x01(\x01R\x01y\x12\x0c\n\x01z\x18\x03 \x01(\x01R\x01z\"\x1a\n\x18InitiateRemoteSshRequest\"a\n\x19InitiateRemoteSshResponse\x12\x12\n\x04port\x18\x01 \x01(\rR\x04port\x12\x18\n\x07\x61\x64\x64ress\x18\x02 \x01(\tR\x07\x61\x64\x64ress\x12\x16\n\x06stsafe\x18\x03 \x01(\x0cR\x06stsafe\"r\n\x15SoftwareUpdateRequest\x12\x1b\n\tstream_id\x18\x01 \x01(\x04R\x08streamId\x12\x12\n\x04\x64\x61ta\x18\x02 \x01(\x0cR\x04\x64\x61ta\x12\x12\n\x04open\x18\x03 \x01(\x08R\x04open\x12\x14\n\x05\x63lose\x18\x04 \x01(\x08R\x05\x63lose\"\x18\n\x16SoftwareUpdateResponse*\xd6\x02\n\nBootReason\x12\x17\n\x13\x42OOT_REASON_UNKNOWN\x10\x00\x12\r\n\tFORGOTTEN\x10\x01\x12\x0f\n\x0bPOWER_CYCLE\x10\x02\x12\x0b\n\x07\x43OMMAND\x10\x03\x12\x13\n\x0fSOFTWARE_UPDATE\x10\x04\x12\x11\n\rCONFIG_UPDATE\x10\x05\x12\x0f\n\x0bUPTIME_FDIR\x10\x06\x12\x11\n\rREPEATER_FDIR\x10\x07\x12\x19\n\x15\x41VIATION_ETH_WAN_FDIR\x10\x08\x12\x10\n\x0cKERNEL_PANIC\x10\t\x12\x1c\n\x18INTENTIONAL_KERNEL_PANIC\x10\x0e\x12\x1b\n\x17MCU_BRINGUP_FAILED_FDIR\x10\x0b\x12\x18\n\x14\x41VIATION_OUTAGE_FDIR\x10\x0c\x12\x15\n\x11SOFTWARE_WATCHDOG\x10\r\"\x04\x08\n\x10\n*\x17\x41VIATION_5M_OUTAGE_FDIRB\xd5\x01\n\x15\x63om.SpaceX.API.DeviceB\x0b\x43ommonProtoP\x01ZIgithub.com/Eitol/starlink-client/libs/golang/client/gen/spacex/api/device\xa2\x02\x03SAD\xaa\x02\x11SpaceX.API.Device\xca\x02\x11SpaceX\\API\\Device\xe2\x02\x1dSpaceX\\API\\Device\\GPBMetadata\xea\x02\x13SpaceX::API::Deviceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'spacex.api.device.common_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.SpaceX.API.DeviceB\013CommonProtoP\001ZIgithub.com/Eitol/starlink-client/libs/golang/client/gen/spacex/api/device\242\002\003SAD\252\002\021SpaceX.API.Device\312\002\021SpaceX\\API\\Device\342\002\035SpaceX\\API\\Device\\GPBMetadata\352\002\023SpaceX::API::Device'
  _globals['_BOOTINFO_COUNTBYREASONENTRY']._loaded_options = None
  _globals['_BOOTINFO_COUNTBYREASONENTRY']._serialized_options = b'8\001'
  _globals['_BOOTINFO_COUNTBYREASONDELTAENTRY']._loaded_options = None
  _globals['_BOOTINFO_COUNTBYREASONDELTAENTRY']._serialized_options = b'8\001'
  _globals['_BOOTREASON']._serialized_start=3831
  _globals['_BOOTREASON']._serialized_end=4173
  _globals['_DEVICEINFO']._serialized_start=54
  _globals['_DEVICEINFO']._serialized_end=639
  _globals['_DEVICESTATE']._serialized_start=641
  _globals['_DEVICESTATE']._serialized_end=681
  _globals['_SIGNEDDATA']._serialized_start=683
  _globals['_SIGNEDDATA']._serialized_end=745
  _globals['_GETNEXTIDREQUEST']._serialized_start=747
  _globals['_GETNEXTIDREQUEST']._serialized_end=765
  _globals['_GETNEXTIDRESPONSE']._serialized_start=767
  _globals['_GETNEXTIDRESPONSE']._serialized_end=829
  _globals['_BOOTINFO']._serialized_start=832
  _globals['_BOOTINFO']._serialized_end=1339
  _globals['_BOOTINFO_COUNTBYREASONENTRY']._serialized_start=1204
  _globals['_BOOTINFO_COUNTBYREASONENTRY']._serialized_end=1268
  _globals['_BOOTINFO_COUNTBYREASONDELTAENTRY']._serialized_start=1270
  _globals['_BOOTINFO_COUNTBYREASONDELTAENTRY']._serialized_end=1339
  _globals['_PINGTARGET']._serialized_start=1341
  _globals['_PINGTARGET']._serialized_end=1433
  _globals['_PINGRESULT']._serialized_start=1435
  _globals['_PINGRESULT']._serialized_end=1560
  _globals['_BONDINGCHALLENGE']._serialized_start=1562
  _globals['_BONDINGCHALLENGE']._serialized_end=1652
  _globals['_AUTHENTICATEREQUEST']._serialized_start=1654
  _globals['_AUTHENTICATEREQUEST']._serialized_end=1736
  _globals['_CHALLENGERESPONSE']._serialized_start=1738
  _globals['_CHALLENGERESPONSE']._serialized_end=1832
  _globals['_NETWORKINTERFACE']._serialized_start=1835
  _globals['_NETWORKINTERFACE']._serialized_end=2520
  _globals['_NETWORKINTERFACE_RXSTATS']._serialized_start=2356
  _globals['_NETWORKINTERFACE_RXSTATS']._serialized_end=2448
  _globals['_NETWORKINTERFACE_TXSTATS']._serialized_start=2450
  _globals['_NETWORKINTERFACE_TXSTATS']._serialized_end=2507
  _globals['_ETHERNETNETWORKINTERFACE']._serialized_start=2523
  _globals['_ETHERNETNETWORKINTERFACE']._serialized_end=2783
  _globals['_ETHERNETNETWORKINTERFACE_DUPLEX']._serialized_start=2742
  _globals['_ETHERNETNETWORKINTERFACE_DUPLEX']._serialized_end=2783
  _globals['_WIFINETWORKINTERFACE']._serialized_start=2786
  _globals['_WIFINETWORKINTERFACE']._serialized_end=3371
  _globals['_WIFINETWORKINTERFACE_INVALIDPACKETCOUNTS']._serialized_start=3092
  _globals['_WIFINETWORKINTERFACE_INVALIDPACKETCOUNTS']._serialized_end=3320
  _globals['_BRIDGENETWORKINTERFACE']._serialized_start=3373
  _globals['_BRIDGENETWORKINTERFACE']._serialized_end=3432
  _globals['_LLAPOSITION']._serialized_start=3434
  _globals['_LLAPOSITION']._serialized_end=3501
  _globals['_ECEFPOSITION']._serialized_start=3503
  _globals['_ECEFPOSITION']._serialized_end=3559
  _globals['_INITIATEREMOTESSHREQUEST']._serialized_start=3561
  _globals['_INITIATEREMOTESSHREQUEST']._serialized_end=3587
  _globals['_INITIATEREMOTESSHRESPONSE']._serialized_start=3589
  _globals['_INITIATEREMOTESSHRESPONSE']._serialized_end=3686
  _globals['_SOFTWAREUPDATEREQUEST']._serialized_start=3688
  _globals['_SOFTWAREUPDATEREQUEST']._serialized_end=3802
  _globals['_SOFTWAREUPDATERESPONSE']._serialized_start=3804
  _globals['_SOFTWAREUPDATERESPONSE']._serialized_end=3828
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Epoch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    UNIX: _ClassVar[Epoch]
    GPS: _ClassVar[Epoch]
UNIX: Epoch
GPS: Epoch

class TimestampInfo(_message.Message):
    __slots__ = ("epoch", "nanoseconds")
    EPOCH_FIELD_NUMBER: _ClassVar[int]
    NANOSECONDS_FIELD_NUMBER: _ClassVar[int]
    epoch: Epoch
    nanoseconds: int
    def __init__(self, epoch: _Optional[_Union[Epoch, str]] = ..., nanoseconds: _Optional[int] = ...) -> None: ...
